"""
Type annotations for iotwireless service type definitions.

[Open documentation](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_iotwireless/type_defs/)

Usage::

    ```python
    from types_aiobotocore_iotwireless.type_defs import SessionKeysAbpV10XTypeDef

    data: SessionKeysAbpV10XTypeDef = {...}
    ```
"""
import sys
from datetime import datetime
from typing import IO, Any, Dict, List, Mapping, Sequence, Union

from aiobotocore.response import StreamingBody

from .literals import (
    BatteryLevelType,
    ConnectionStatusType,
    DeviceProfileTypeType,
    DeviceStateType,
    DlClassType,
    DownlinkModeType,
    EventNotificationResourceTypeType,
    EventNotificationTopicStatusType,
    EventType,
    ExpressionTypeType,
    FuotaDeviceStatusType,
    FuotaTaskStatusType,
    IdentifierTypeType,
    ImportTaskStatusType,
    LogLevelType,
    MessageTypeType,
    MulticastFrameInfoType,
    OnboardStatusType,
    PositionConfigurationFecType,
    PositionConfigurationStatusType,
    PositioningConfigStatusType,
    PositionResourceTypeType,
    SigningAlgType,
    SupportedRfRegionType,
    WirelessDeviceEventType,
    WirelessDeviceFrameInfoType,
    WirelessDeviceIdTypeType,
    WirelessDeviceSidewalkStatusType,
    WirelessDeviceTypeType,
    WirelessGatewayEventType,
    WirelessGatewayIdTypeType,
    WirelessGatewayServiceTypeType,
    WirelessGatewayTaskStatusType,
)

if sys.version_info >= (3, 9):
    from typing import Literal
else:
    from typing_extensions import Literal
if sys.version_info >= (3, 9):
    from typing import TypedDict
else:
    from typing_extensions import TypedDict


__all__ = (
    "SessionKeysAbpV10XTypeDef",
    "SessionKeysAbpV11TypeDef",
    "AccuracyTypeDef",
    "ApplicationConfigTypeDef",
    "SidewalkAccountInfoTypeDef",
    "TagTypeDef",
    "AssociateMulticastGroupWithFuotaTaskRequestRequestTypeDef",
    "AssociateWirelessDeviceWithFuotaTaskRequestRequestTypeDef",
    "AssociateWirelessDeviceWithMulticastGroupRequestRequestTypeDef",
    "AssociateWirelessDeviceWithThingRequestRequestTypeDef",
    "AssociateWirelessGatewayWithCertificateRequestRequestTypeDef",
    "AssociateWirelessGatewayWithCertificateResponseTypeDef",
    "AssociateWirelessGatewayWithThingRequestRequestTypeDef",
    "BeaconingTypeDef",
    "CancelMulticastGroupSessionRequestRequestTypeDef",
    "CdmaLocalIdTypeDef",
    "CdmaNmrObjTypeDef",
    "CertificateListTypeDef",
    "LoRaWANConnectionStatusEventNotificationConfigurationsTypeDef",
    "LoRaWANConnectionStatusResourceTypeEventConfigurationTypeDef",
    "CreateDestinationResponseTypeDef",
    "LoRaWANDeviceProfileTypeDef",
    "CreateDeviceProfileResponseTypeDef",
    "LoRaWANFuotaTaskTypeDef",
    "CreateFuotaTaskResponseTypeDef",
    "LoRaWANMulticastTypeDef",
    "CreateMulticastGroupResponseTypeDef",
    "TraceContentTypeDef",
    "CreateNetworkAnalyzerConfigurationResponseTypeDef",
    "LoRaWANServiceProfileTypeDef",
    "CreateServiceProfileResponseTypeDef",
    "SidewalkCreateWirelessDeviceTypeDef",
    "CreateWirelessDeviceResponseTypeDef",
    "CreateWirelessGatewayResponseTypeDef",
    "CreateWirelessGatewayTaskDefinitionResponseTypeDef",
    "CreateWirelessGatewayTaskRequestRequestTypeDef",
    "CreateWirelessGatewayTaskResponseTypeDef",
    "DakCertificateMetadataTypeDef",
    "DeleteDestinationRequestRequestTypeDef",
    "DeleteDeviceProfileRequestRequestTypeDef",
    "DeleteFuotaTaskRequestRequestTypeDef",
    "DeleteMulticastGroupRequestRequestTypeDef",
    "DeleteNetworkAnalyzerConfigurationRequestRequestTypeDef",
    "DeleteQueuedMessagesRequestRequestTypeDef",
    "DeleteServiceProfileRequestRequestTypeDef",
    "DeleteWirelessDeviceImportTaskRequestRequestTypeDef",
    "DeleteWirelessDeviceRequestRequestTypeDef",
    "DeleteWirelessGatewayRequestRequestTypeDef",
    "DeleteWirelessGatewayTaskDefinitionRequestRequestTypeDef",
    "DeleteWirelessGatewayTaskRequestRequestTypeDef",
    "DeregisterWirelessDeviceRequestRequestTypeDef",
    "DestinationsTypeDef",
    "DeviceProfileTypeDef",
    "SidewalkEventNotificationConfigurationsTypeDef",
    "SidewalkResourceTypeEventConfigurationTypeDef",
    "DisassociateAwsAccountFromPartnerAccountRequestRequestTypeDef",
    "DisassociateMulticastGroupFromFuotaTaskRequestRequestTypeDef",
    "DisassociateWirelessDeviceFromFuotaTaskRequestRequestTypeDef",
    "DisassociateWirelessDeviceFromMulticastGroupRequestRequestTypeDef",
    "DisassociateWirelessDeviceFromThingRequestRequestTypeDef",
    "DisassociateWirelessGatewayFromCertificateRequestRequestTypeDef",
    "DisassociateWirelessGatewayFromThingRequestRequestTypeDef",
    "PositioningTypeDef",
    "FuotaTaskTypeDef",
    "GatewayListItemTypeDef",
    "GetDestinationRequestRequestTypeDef",
    "GetDestinationResponseTypeDef",
    "GetDeviceProfileRequestRequestTypeDef",
    "GetFuotaTaskRequestRequestTypeDef",
    "LoRaWANFuotaTaskGetInfoTypeDef",
    "GetMulticastGroupRequestRequestTypeDef",
    "LoRaWANMulticastGetTypeDef",
    "GetMulticastGroupSessionRequestRequestTypeDef",
    "LoRaWANMulticastSessionTypeDef",
    "GetNetworkAnalyzerConfigurationRequestRequestTypeDef",
    "GetPartnerAccountRequestRequestTypeDef",
    "SidewalkAccountInfoWithFingerprintTypeDef",
    "GetPositionConfigurationRequestRequestTypeDef",
    "GnssTypeDef",
    "IpTypeDef",
    "WiFiAccessPointTypeDef",
    "GetPositionEstimateResponseTypeDef",
    "GetPositionRequestRequestTypeDef",
    "GetResourceEventConfigurationRequestRequestTypeDef",
    "GetResourceLogLevelRequestRequestTypeDef",
    "GetResourceLogLevelResponseTypeDef",
    "GetResourcePositionRequestRequestTypeDef",
    "GetResourcePositionResponseTypeDef",
    "GetServiceEndpointRequestRequestTypeDef",
    "GetServiceEndpointResponseTypeDef",
    "GetServiceProfileRequestRequestTypeDef",
    "LoRaWANGetServiceProfileInfoTypeDef",
    "GetWirelessDeviceImportTaskRequestRequestTypeDef",
    "SidewalkGetStartImportInfoTypeDef",
    "GetWirelessDeviceRequestRequestTypeDef",
    "GetWirelessDeviceStatisticsRequestRequestTypeDef",
    "SidewalkDeviceMetadataTypeDef",
    "GetWirelessGatewayCertificateRequestRequestTypeDef",
    "GetWirelessGatewayCertificateResponseTypeDef",
    "GetWirelessGatewayFirmwareInformationRequestRequestTypeDef",
    "GetWirelessGatewayRequestRequestTypeDef",
    "GetWirelessGatewayStatisticsRequestRequestTypeDef",
    "GetWirelessGatewayStatisticsResponseTypeDef",
    "GetWirelessGatewayTaskDefinitionRequestRequestTypeDef",
    "GetWirelessGatewayTaskRequestRequestTypeDef",
    "GetWirelessGatewayTaskResponseTypeDef",
    "GlobalIdentityTypeDef",
    "GsmLocalIdTypeDef",
    "ImportedSidewalkDeviceTypeDef",
    "LoRaWANJoinEventNotificationConfigurationsTypeDef",
    "LoRaWANJoinResourceTypeEventConfigurationTypeDef",
    "ListDestinationsRequestRequestTypeDef",
    "ListDeviceProfilesRequestRequestTypeDef",
    "ListDevicesForWirelessDeviceImportTaskRequestRequestTypeDef",
    "ListEventConfigurationsRequestRequestTypeDef",
    "ListFuotaTasksRequestRequestTypeDef",
    "ListMulticastGroupsByFuotaTaskRequestRequestTypeDef",
    "MulticastGroupByFuotaTaskTypeDef",
    "ListMulticastGroupsRequestRequestTypeDef",
    "MulticastGroupTypeDef",
    "ListNetworkAnalyzerConfigurationsRequestRequestTypeDef",
    "NetworkAnalyzerConfigurationsTypeDef",
    "ListPartnerAccountsRequestRequestTypeDef",
    "ListPositionConfigurationsRequestRequestTypeDef",
    "ListQueuedMessagesRequestRequestTypeDef",
    "ListServiceProfilesRequestRequestTypeDef",
    "ServiceProfileTypeDef",
    "ListTagsForResourceRequestRequestTypeDef",
    "ListWirelessDeviceImportTasksRequestRequestTypeDef",
    "ListWirelessDevicesRequestRequestTypeDef",
    "ListWirelessGatewayTaskDefinitionsRequestRequestTypeDef",
    "ListWirelessGatewaysRequestRequestTypeDef",
    "LoRaWANGatewayMetadataTypeDef",
    "OtaaV10XTypeDef",
    "OtaaV11TypeDef",
    "LoRaWANGatewayVersionTypeDef",
    "LoRaWANListDeviceTypeDef",
    "LoRaWANMulticastMetadataTypeDef",
    "LoRaWANStartFuotaTaskTypeDef",
    "UpdateAbpV10XTypeDef",
    "UpdateAbpV11TypeDef",
    "LteLocalIdTypeDef",
    "LteNmrObjTypeDef",
    "SemtechGnssConfigurationTypeDef",
    "SemtechGnssDetailTypeDef",
    "PutResourceLogLevelRequestRequestTypeDef",
    "ResetResourceLogLevelRequestRequestTypeDef",
    "ResponseMetadataTypeDef",
    "SendDataToMulticastGroupResponseTypeDef",
    "SendDataToWirelessDeviceResponseTypeDef",
    "SidewalkSendDataToDeviceTypeDef",
    "SidewalkSingleStartImportInfoTypeDef",
    "SidewalkStartImportInfoTypeDef",
    "SidewalkUpdateAccountTypeDef",
    "SidewalkUpdateImportInfoTypeDef",
    "StartSingleWirelessDeviceImportTaskResponseTypeDef",
    "StartWirelessDeviceImportTaskResponseTypeDef",
    "TdscdmaLocalIdTypeDef",
    "TdscdmaNmrObjTypeDef",
    "TestWirelessDeviceRequestRequestTypeDef",
    "TestWirelessDeviceResponseTypeDef",
    "UntagResourceRequestRequestTypeDef",
    "UpdateDestinationRequestRequestTypeDef",
    "UpdatePositionRequestRequestTypeDef",
    "UpdateResourcePositionRequestRequestTypeDef",
    "UpdateWirelessGatewayRequestRequestTypeDef",
    "WcdmaLocalIdTypeDef",
    "WcdmaNmrObjTypeDef",
    "WirelessDeviceEventLogOptionTypeDef",
    "WirelessGatewayEventLogOptionTypeDef",
    "AbpV10XTypeDef",
    "AbpV11TypeDef",
    "GetPositionResponseTypeDef",
    "AssociateAwsAccountWithPartnerAccountResponseTypeDef",
    "AssociateAwsAccountWithPartnerAccountRequestRequestTypeDef",
    "CreateDestinationRequestRequestTypeDef",
    "ListTagsForResourceResponseTypeDef",
    "StartBulkAssociateWirelessDeviceWithMulticastGroupRequestRequestTypeDef",
    "StartBulkDisassociateWirelessDeviceFromMulticastGroupRequestRequestTypeDef",
    "TagResourceRequestRequestTypeDef",
    "LoRaWANGatewayTypeDef",
    "CdmaObjTypeDef",
    "SidewalkDeviceTypeDef",
    "SidewalkListDeviceTypeDef",
    "ConnectionStatusEventConfigurationTypeDef",
    "ConnectionStatusResourceTypeEventConfigurationTypeDef",
    "CreateDeviceProfileRequestRequestTypeDef",
    "CreateFuotaTaskRequestRequestTypeDef",
    "UpdateFuotaTaskRequestRequestTypeDef",
    "CreateMulticastGroupRequestRequestTypeDef",
    "UpdateMulticastGroupRequestRequestTypeDef",
    "CreateNetworkAnalyzerConfigurationRequestRequestTypeDef",
    "GetNetworkAnalyzerConfigurationResponseTypeDef",
    "UpdateNetworkAnalyzerConfigurationRequestRequestTypeDef",
    "CreateServiceProfileRequestRequestTypeDef",
    "SidewalkGetDeviceProfileTypeDef",
    "ListDestinationsResponseTypeDef",
    "ListDeviceProfilesResponseTypeDef",
    "DeviceRegistrationStateEventConfigurationTypeDef",
    "MessageDeliveryStatusEventConfigurationTypeDef",
    "ProximityEventConfigurationTypeDef",
    "DeviceRegistrationStateResourceTypeEventConfigurationTypeDef",
    "MessageDeliveryStatusResourceTypeEventConfigurationTypeDef",
    "ProximityResourceTypeEventConfigurationTypeDef",
    "FPortsTypeDef",
    "UpdateFPortsTypeDef",
    "ListFuotaTasksResponseTypeDef",
    "ParticipatingGatewaysTypeDef",
    "GetFuotaTaskResponseTypeDef",
    "GetMulticastGroupResponseTypeDef",
    "GetMulticastGroupSessionResponseTypeDef",
    "StartMulticastGroupSessionRequestRequestTypeDef",
    "GetPartnerAccountResponseTypeDef",
    "ListPartnerAccountsResponseTypeDef",
    "GetServiceProfileResponseTypeDef",
    "GetWirelessDeviceImportTaskResponseTypeDef",
    "WirelessDeviceImportTaskTypeDef",
    "GsmNmrObjTypeDef",
    "ImportedWirelessDeviceTypeDef",
    "JoinEventConfigurationTypeDef",
    "JoinResourceTypeEventConfigurationTypeDef",
    "ListMulticastGroupsByFuotaTaskResponseTypeDef",
    "ListMulticastGroupsResponseTypeDef",
    "ListNetworkAnalyzerConfigurationsResponseTypeDef",
    "ListServiceProfilesResponseTypeDef",
    "LoRaWANDeviceMetadataTypeDef",
    "LoRaWANGatewayCurrentVersionTypeDef",
    "LoRaWANUpdateGatewayTaskCreateTypeDef",
    "LoRaWANUpdateGatewayTaskEntryTypeDef",
    "MulticastWirelessMetadataTypeDef",
    "StartFuotaTaskRequestRequestTypeDef",
    "LteObjTypeDef",
    "PositionSolverConfigurationsTypeDef",
    "PositionSolverDetailsTypeDef",
    "StartSingleWirelessDeviceImportTaskRequestRequestTypeDef",
    "StartWirelessDeviceImportTaskRequestRequestTypeDef",
    "UpdatePartnerAccountRequestRequestTypeDef",
    "UpdateWirelessDeviceImportTaskRequestRequestTypeDef",
    "TdscdmaObjTypeDef",
    "WcdmaObjTypeDef",
    "WirelessDeviceLogOptionTypeDef",
    "WirelessGatewayLogOptionTypeDef",
    "CreateWirelessGatewayRequestRequestTypeDef",
    "GetWirelessGatewayResponseTypeDef",
    "WirelessGatewayStatisticsTypeDef",
    "WirelessDeviceStatisticsTypeDef",
    "GetDeviceProfileResponseTypeDef",
    "LoRaWANDeviceTypeDef",
    "LoRaWANUpdateDeviceTypeDef",
    "LoRaWANSendDataToDeviceTypeDef",
    "ListWirelessDeviceImportTasksResponseTypeDef",
    "GsmObjTypeDef",
    "ListDevicesForWirelessDeviceImportTaskResponseTypeDef",
    "EventNotificationItemConfigurationsTypeDef",
    "GetResourceEventConfigurationResponseTypeDef",
    "UpdateResourceEventConfigurationRequestRequestTypeDef",
    "GetEventConfigurationByResourceTypesResponseTypeDef",
    "UpdateEventConfigurationByResourceTypesRequestRequestTypeDef",
    "GetWirelessDeviceStatisticsResponseTypeDef",
    "GetWirelessGatewayFirmwareInformationResponseTypeDef",
    "UpdateWirelessGatewayTaskCreateTypeDef",
    "UpdateWirelessGatewayTaskEntryTypeDef",
    "SendDataToMulticastGroupRequestRequestTypeDef",
    "PutPositionConfigurationRequestRequestTypeDef",
    "GetPositionConfigurationResponseTypeDef",
    "PositionConfigurationItemTypeDef",
    "GetLogLevelsByResourceTypesResponseTypeDef",
    "UpdateLogLevelsByResourceTypesRequestRequestTypeDef",
    "ListWirelessGatewaysResponseTypeDef",
    "ListWirelessDevicesResponseTypeDef",
    "CreateWirelessDeviceRequestRequestTypeDef",
    "GetWirelessDeviceResponseTypeDef",
    "UpdateWirelessDeviceRequestRequestTypeDef",
    "DownlinkQueueMessageTypeDef",
    "WirelessMetadataTypeDef",
    "CellTowersTypeDef",
    "EventConfigurationItemTypeDef",
    "CreateWirelessGatewayTaskDefinitionRequestRequestTypeDef",
    "GetWirelessGatewayTaskDefinitionResponseTypeDef",
    "ListWirelessGatewayTaskDefinitionsResponseTypeDef",
    "ListPositionConfigurationsResponseTypeDef",
    "ListQueuedMessagesResponseTypeDef",
    "SendDataToWirelessDeviceRequestRequestTypeDef",
    "GetPositionEstimateRequestRequestTypeDef",
    "ListEventConfigurationsResponseTypeDef",
)

SessionKeysAbpV10XTypeDef = TypedDict(
    "SessionKeysAbpV10XTypeDef",
    {
        "NwkSKey": str,
        "AppSKey": str,
    },
    total=False,
)

SessionKeysAbpV11TypeDef = TypedDict(
    "SessionKeysAbpV11TypeDef",
    {
        "FNwkSIntKey": str,
        "SNwkSIntKey": str,
        "NwkSEncKey": str,
        "AppSKey": str,
    },
    total=False,
)

AccuracyTypeDef = TypedDict(
    "AccuracyTypeDef",
    {
        "HorizontalAccuracy": float,
        "VerticalAccuracy": float,
    },
    total=False,
)

ApplicationConfigTypeDef = TypedDict(
    "ApplicationConfigTypeDef",
    {
        "FPort": int,
        "Type": Literal["SemtechGeolocation"],
        "DestinationName": str,
    },
    total=False,
)

SidewalkAccountInfoTypeDef = TypedDict(
    "SidewalkAccountInfoTypeDef",
    {
        "AmazonId": str,
        "AppServerPrivateKey": str,
    },
    total=False,
)

TagTypeDef = TypedDict(
    "TagTypeDef",
    {
        "Key": str,
        "Value": str,
    },
)

AssociateMulticastGroupWithFuotaTaskRequestRequestTypeDef = TypedDict(
    "AssociateMulticastGroupWithFuotaTaskRequestRequestTypeDef",
    {
        "Id": str,
        "MulticastGroupId": str,
    },
)

AssociateWirelessDeviceWithFuotaTaskRequestRequestTypeDef = TypedDict(
    "AssociateWirelessDeviceWithFuotaTaskRequestRequestTypeDef",
    {
        "Id": str,
        "WirelessDeviceId": str,
    },
)

AssociateWirelessDeviceWithMulticastGroupRequestRequestTypeDef = TypedDict(
    "AssociateWirelessDeviceWithMulticastGroupRequestRequestTypeDef",
    {
        "Id": str,
        "WirelessDeviceId": str,
    },
)

AssociateWirelessDeviceWithThingRequestRequestTypeDef = TypedDict(
    "AssociateWirelessDeviceWithThingRequestRequestTypeDef",
    {
        "Id": str,
        "ThingArn": str,
    },
)

AssociateWirelessGatewayWithCertificateRequestRequestTypeDef = TypedDict(
    "AssociateWirelessGatewayWithCertificateRequestRequestTypeDef",
    {
        "Id": str,
        "IotCertificateId": str,
    },
)

AssociateWirelessGatewayWithCertificateResponseTypeDef = TypedDict(
    "AssociateWirelessGatewayWithCertificateResponseTypeDef",
    {
        "IotCertificateId": str,
        "ResponseMetadata": "ResponseMetadataTypeDef",
    },
)

AssociateWirelessGatewayWithThingRequestRequestTypeDef = TypedDict(
    "AssociateWirelessGatewayWithThingRequestRequestTypeDef",
    {
        "Id": str,
        "ThingArn": str,
    },
)

BeaconingTypeDef = TypedDict(
    "BeaconingTypeDef",
    {
        "DataRate": int,
        "Frequencies": Sequence[int],
    },
    total=False,
)

CancelMulticastGroupSessionRequestRequestTypeDef = TypedDict(
    "CancelMulticastGroupSessionRequestRequestTypeDef",
    {
        "Id": str,
    },
)

CdmaLocalIdTypeDef = TypedDict(
    "CdmaLocalIdTypeDef",
    {
        "PnOffset": int,
        "CdmaChannel": int,
    },
)

_RequiredCdmaNmrObjTypeDef = TypedDict(
    "_RequiredCdmaNmrObjTypeDef",
    {
        "PnOffset": int,
        "CdmaChannel": int,
    },
)
_OptionalCdmaNmrObjTypeDef = TypedDict(
    "_OptionalCdmaNmrObjTypeDef",
    {
        "PilotPower": int,
        "BaseStationId": int,
    },
    total=False,
)


class CdmaNmrObjTypeDef(_RequiredCdmaNmrObjTypeDef, _OptionalCdmaNmrObjTypeDef):
    pass


CertificateListTypeDef = TypedDict(
    "CertificateListTypeDef",
    {
        "SigningAlg": SigningAlgType,
        "Value": str,
    },
)

LoRaWANConnectionStatusEventNotificationConfigurationsTypeDef = TypedDict(
    "LoRaWANConnectionStatusEventNotificationConfigurationsTypeDef",
    {
        "GatewayEuiEventTopic": EventNotificationTopicStatusType,
    },
    total=False,
)

LoRaWANConnectionStatusResourceTypeEventConfigurationTypeDef = TypedDict(
    "LoRaWANConnectionStatusResourceTypeEventConfigurationTypeDef",
    {
        "WirelessGatewayEventTopic": EventNotificationTopicStatusType,
    },
    total=False,
)

CreateDestinationResponseTypeDef = TypedDict(
    "CreateDestinationResponseTypeDef",
    {
        "Arn": str,
        "Name": str,
        "ResponseMetadata": "ResponseMetadataTypeDef",
    },
)

LoRaWANDeviceProfileTypeDef = TypedDict(
    "LoRaWANDeviceProfileTypeDef",
    {
        "SupportsClassB": bool,
        "ClassBTimeout": int,
        "PingSlotPeriod": int,
        "PingSlotDr": int,
        "PingSlotFreq": int,
        "SupportsClassC": bool,
        "ClassCTimeout": int,
        "MacVersion": str,
        "RegParamsRevision": str,
        "RxDelay1": int,
        "RxDrOffset1": int,
        "RxDataRate2": int,
        "RxFreq2": int,
        "FactoryPresetFreqsList": Sequence[int],
        "MaxEirp": int,
        "MaxDutyCycle": int,
        "RfRegion": str,
        "SupportsJoin": bool,
        "Supports32BitFCnt": bool,
    },
    total=False,
)

CreateDeviceProfileResponseTypeDef = TypedDict(
    "CreateDeviceProfileResponseTypeDef",
    {
        "Arn": str,
        "Id": str,
        "ResponseMetadata": "ResponseMetadataTypeDef",
    },
)

LoRaWANFuotaTaskTypeDef = TypedDict(
    "LoRaWANFuotaTaskTypeDef",
    {
        "RfRegion": SupportedRfRegionType,
    },
    total=False,
)

CreateFuotaTaskResponseTypeDef = TypedDict(
    "CreateFuotaTaskResponseTypeDef",
    {
        "Arn": str,
        "Id": str,
        "ResponseMetadata": "ResponseMetadataTypeDef",
    },
)

LoRaWANMulticastTypeDef = TypedDict(
    "LoRaWANMulticastTypeDef",
    {
        "RfRegion": SupportedRfRegionType,
        "DlClass": DlClassType,
    },
    total=False,
)

CreateMulticastGroupResponseTypeDef = TypedDict(
    "CreateMulticastGroupResponseTypeDef",
    {
        "Arn": str,
        "Id": str,
        "ResponseMetadata": "ResponseMetadataTypeDef",
    },
)

TraceContentTypeDef = TypedDict(
    "TraceContentTypeDef",
    {
        "WirelessDeviceFrameInfo": WirelessDeviceFrameInfoType,
        "LogLevel": LogLevelType,
        "MulticastFrameInfo": MulticastFrameInfoType,
    },
    total=False,
)

CreateNetworkAnalyzerConfigurationResponseTypeDef = TypedDict(
    "CreateNetworkAnalyzerConfigurationResponseTypeDef",
    {
        "Arn": str,
        "Name": str,
        "ResponseMetadata": "ResponseMetadataTypeDef",
    },
)

LoRaWANServiceProfileTypeDef = TypedDict(
    "LoRaWANServiceProfileTypeDef",
    {
        "AddGwMetadata": bool,
        "DrMin": int,
        "DrMax": int,
        "PrAllowed": bool,
        "RaAllowed": bool,
    },
    total=False,
)

CreateServiceProfileResponseTypeDef = TypedDict(
    "CreateServiceProfileResponseTypeDef",
    {
        "Arn": str,
        "Id": str,
        "ResponseMetadata": "ResponseMetadataTypeDef",
    },
)

SidewalkCreateWirelessDeviceTypeDef = TypedDict(
    "SidewalkCreateWirelessDeviceTypeDef",
    {
        "DeviceProfileId": str,
    },
    total=False,
)

CreateWirelessDeviceResponseTypeDef = TypedDict(
    "CreateWirelessDeviceResponseTypeDef",
    {
        "Arn": str,
        "Id": str,
        "ResponseMetadata": "ResponseMetadataTypeDef",
    },
)

CreateWirelessGatewayResponseTypeDef = TypedDict(
    "CreateWirelessGatewayResponseTypeDef",
    {
        "Arn": str,
        "Id": str,
        "ResponseMetadata": "ResponseMetadataTypeDef",
    },
)

CreateWirelessGatewayTaskDefinitionResponseTypeDef = TypedDict(
    "CreateWirelessGatewayTaskDefinitionResponseTypeDef",
    {
        "Id": str,
        "Arn": str,
        "ResponseMetadata": "ResponseMetadataTypeDef",
    },
)

CreateWirelessGatewayTaskRequestRequestTypeDef = TypedDict(
    "CreateWirelessGatewayTaskRequestRequestTypeDef",
    {
        "Id": str,
        "WirelessGatewayTaskDefinitionId": str,
    },
)

CreateWirelessGatewayTaskResponseTypeDef = TypedDict(
    "CreateWirelessGatewayTaskResponseTypeDef",
    {
        "WirelessGatewayTaskDefinitionId": str,
        "Status": WirelessGatewayTaskStatusType,
        "ResponseMetadata": "ResponseMetadataTypeDef",
    },
)

_RequiredDakCertificateMetadataTypeDef = TypedDict(
    "_RequiredDakCertificateMetadataTypeDef",
    {
        "CertificateId": str,
    },
)
_OptionalDakCertificateMetadataTypeDef = TypedDict(
    "_OptionalDakCertificateMetadataTypeDef",
    {
        "MaxAllowedSignature": int,
        "FactorySupport": bool,
        "ApId": str,
        "DeviceTypeId": str,
    },
    total=False,
)


class DakCertificateMetadataTypeDef(
    _RequiredDakCertificateMetadataTypeDef, _OptionalDakCertificateMetadataTypeDef
):
    pass


DeleteDestinationRequestRequestTypeDef = TypedDict(
    "DeleteDestinationRequestRequestTypeDef",
    {
        "Name": str,
    },
)

DeleteDeviceProfileRequestRequestTypeDef = TypedDict(
    "DeleteDeviceProfileRequestRequestTypeDef",
    {
        "Id": str,
    },
)

DeleteFuotaTaskRequestRequestTypeDef = TypedDict(
    "DeleteFuotaTaskRequestRequestTypeDef",
    {
        "Id": str,
    },
)

DeleteMulticastGroupRequestRequestTypeDef = TypedDict(
    "DeleteMulticastGroupRequestRequestTypeDef",
    {
        "Id": str,
    },
)

DeleteNetworkAnalyzerConfigurationRequestRequestTypeDef = TypedDict(
    "DeleteNetworkAnalyzerConfigurationRequestRequestTypeDef",
    {
        "ConfigurationName": str,
    },
)

_RequiredDeleteQueuedMessagesRequestRequestTypeDef = TypedDict(
    "_RequiredDeleteQueuedMessagesRequestRequestTypeDef",
    {
        "Id": str,
        "MessageId": str,
    },
)
_OptionalDeleteQueuedMessagesRequestRequestTypeDef = TypedDict(
    "_OptionalDeleteQueuedMessagesRequestRequestTypeDef",
    {
        "WirelessDeviceType": WirelessDeviceTypeType,
    },
    total=False,
)


class DeleteQueuedMessagesRequestRequestTypeDef(
    _RequiredDeleteQueuedMessagesRequestRequestTypeDef,
    _OptionalDeleteQueuedMessagesRequestRequestTypeDef,
):
    pass


DeleteServiceProfileRequestRequestTypeDef = TypedDict(
    "DeleteServiceProfileRequestRequestTypeDef",
    {
        "Id": str,
    },
)

DeleteWirelessDeviceImportTaskRequestRequestTypeDef = TypedDict(
    "DeleteWirelessDeviceImportTaskRequestRequestTypeDef",
    {
        "Id": str,
    },
)

DeleteWirelessDeviceRequestRequestTypeDef = TypedDict(
    "DeleteWirelessDeviceRequestRequestTypeDef",
    {
        "Id": str,
    },
)

DeleteWirelessGatewayRequestRequestTypeDef = TypedDict(
    "DeleteWirelessGatewayRequestRequestTypeDef",
    {
        "Id": str,
    },
)

DeleteWirelessGatewayTaskDefinitionRequestRequestTypeDef = TypedDict(
    "DeleteWirelessGatewayTaskDefinitionRequestRequestTypeDef",
    {
        "Id": str,
    },
)

DeleteWirelessGatewayTaskRequestRequestTypeDef = TypedDict(
    "DeleteWirelessGatewayTaskRequestRequestTypeDef",
    {
        "Id": str,
    },
)

_RequiredDeregisterWirelessDeviceRequestRequestTypeDef = TypedDict(
    "_RequiredDeregisterWirelessDeviceRequestRequestTypeDef",
    {
        "Identifier": str,
    },
)
_OptionalDeregisterWirelessDeviceRequestRequestTypeDef = TypedDict(
    "_OptionalDeregisterWirelessDeviceRequestRequestTypeDef",
    {
        "WirelessDeviceType": WirelessDeviceTypeType,
    },
    total=False,
)


class DeregisterWirelessDeviceRequestRequestTypeDef(
    _RequiredDeregisterWirelessDeviceRequestRequestTypeDef,
    _OptionalDeregisterWirelessDeviceRequestRequestTypeDef,
):
    pass


DestinationsTypeDef = TypedDict(
    "DestinationsTypeDef",
    {
        "Arn": str,
        "Name": str,
        "ExpressionType": ExpressionTypeType,
        "Expression": str,
        "Description": str,
        "RoleArn": str,
    },
    total=False,
)

DeviceProfileTypeDef = TypedDict(
    "DeviceProfileTypeDef",
    {
        "Arn": str,
        "Name": str,
        "Id": str,
    },
    total=False,
)

SidewalkEventNotificationConfigurationsTypeDef = TypedDict(
    "SidewalkEventNotificationConfigurationsTypeDef",
    {
        "AmazonIdEventTopic": EventNotificationTopicStatusType,
    },
    total=False,
)

SidewalkResourceTypeEventConfigurationTypeDef = TypedDict(
    "SidewalkResourceTypeEventConfigurationTypeDef",
    {
        "WirelessDeviceEventTopic": EventNotificationTopicStatusType,
    },
    total=False,
)

DisassociateAwsAccountFromPartnerAccountRequestRequestTypeDef = TypedDict(
    "DisassociateAwsAccountFromPartnerAccountRequestRequestTypeDef",
    {
        "PartnerAccountId": str,
        "PartnerType": Literal["Sidewalk"],
    },
)

DisassociateMulticastGroupFromFuotaTaskRequestRequestTypeDef = TypedDict(
    "DisassociateMulticastGroupFromFuotaTaskRequestRequestTypeDef",
    {
        "Id": str,
        "MulticastGroupId": str,
    },
)

DisassociateWirelessDeviceFromFuotaTaskRequestRequestTypeDef = TypedDict(
    "DisassociateWirelessDeviceFromFuotaTaskRequestRequestTypeDef",
    {
        "Id": str,
        "WirelessDeviceId": str,
    },
)

DisassociateWirelessDeviceFromMulticastGroupRequestRequestTypeDef = TypedDict(
    "DisassociateWirelessDeviceFromMulticastGroupRequestRequestTypeDef",
    {
        "Id": str,
        "WirelessDeviceId": str,
    },
)

DisassociateWirelessDeviceFromThingRequestRequestTypeDef = TypedDict(
    "DisassociateWirelessDeviceFromThingRequestRequestTypeDef",
    {
        "Id": str,
    },
)

DisassociateWirelessGatewayFromCertificateRequestRequestTypeDef = TypedDict(
    "DisassociateWirelessGatewayFromCertificateRequestRequestTypeDef",
    {
        "Id": str,
    },
)

DisassociateWirelessGatewayFromThingRequestRequestTypeDef = TypedDict(
    "DisassociateWirelessGatewayFromThingRequestRequestTypeDef",
    {
        "Id": str,
    },
)

PositioningTypeDef = TypedDict(
    "PositioningTypeDef",
    {
        "ClockSync": int,
        "Stream": int,
        "Gnss": int,
    },
    total=False,
)

FuotaTaskTypeDef = TypedDict(
    "FuotaTaskTypeDef",
    {
        "Id": str,
        "Arn": str,
        "Name": str,
    },
    total=False,
)

GatewayListItemTypeDef = TypedDict(
    "GatewayListItemTypeDef",
    {
        "GatewayId": str,
        "DownlinkFrequency": int,
    },
)

GetDestinationRequestRequestTypeDef = TypedDict(
    "GetDestinationRequestRequestTypeDef",
    {
        "Name": str,
    },
)

GetDestinationResponseTypeDef = TypedDict(
    "GetDestinationResponseTypeDef",
    {
        "Arn": str,
        "Name": str,
        "Expression": str,
        "ExpressionType": ExpressionTypeType,
        "Description": str,
        "RoleArn": str,
        "ResponseMetadata": "ResponseMetadataTypeDef",
    },
)

GetDeviceProfileRequestRequestTypeDef = TypedDict(
    "GetDeviceProfileRequestRequestTypeDef",
    {
        "Id": str,
    },
)

GetFuotaTaskRequestRequestTypeDef = TypedDict(
    "GetFuotaTaskRequestRequestTypeDef",
    {
        "Id": str,
    },
)

LoRaWANFuotaTaskGetInfoTypeDef = TypedDict(
    "LoRaWANFuotaTaskGetInfoTypeDef",
    {
        "RfRegion": str,
        "StartTime": datetime,
    },
    total=False,
)

GetMulticastGroupRequestRequestTypeDef = TypedDict(
    "GetMulticastGroupRequestRequestTypeDef",
    {
        "Id": str,
    },
)

LoRaWANMulticastGetTypeDef = TypedDict(
    "LoRaWANMulticastGetTypeDef",
    {
        "RfRegion": SupportedRfRegionType,
        "DlClass": DlClassType,
        "NumberOfDevicesRequested": int,
        "NumberOfDevicesInGroup": int,
    },
    total=False,
)

GetMulticastGroupSessionRequestRequestTypeDef = TypedDict(
    "GetMulticastGroupSessionRequestRequestTypeDef",
    {
        "Id": str,
    },
)

LoRaWANMulticastSessionTypeDef = TypedDict(
    "LoRaWANMulticastSessionTypeDef",
    {
        "DlDr": int,
        "DlFreq": int,
        "SessionStartTime": datetime,
        "SessionTimeout": int,
        "PingSlotPeriod": int,
    },
    total=False,
)

GetNetworkAnalyzerConfigurationRequestRequestTypeDef = TypedDict(
    "GetNetworkAnalyzerConfigurationRequestRequestTypeDef",
    {
        "ConfigurationName": str,
    },
)

GetPartnerAccountRequestRequestTypeDef = TypedDict(
    "GetPartnerAccountRequestRequestTypeDef",
    {
        "PartnerAccountId": str,
        "PartnerType": Literal["Sidewalk"],
    },
)

SidewalkAccountInfoWithFingerprintTypeDef = TypedDict(
    "SidewalkAccountInfoWithFingerprintTypeDef",
    {
        "AmazonId": str,
        "Fingerprint": str,
        "Arn": str,
    },
    total=False,
)

GetPositionConfigurationRequestRequestTypeDef = TypedDict(
    "GetPositionConfigurationRequestRequestTypeDef",
    {
        "ResourceIdentifier": str,
        "ResourceType": PositionResourceTypeType,
    },
)

_RequiredGnssTypeDef = TypedDict(
    "_RequiredGnssTypeDef",
    {
        "Payload": str,
    },
)
_OptionalGnssTypeDef = TypedDict(
    "_OptionalGnssTypeDef",
    {
        "CaptureTime": float,
        "CaptureTimeAccuracy": float,
        "AssistPosition": Sequence[float],
        "AssistAltitude": float,
        "Use2DSolver": bool,
    },
    total=False,
)


class GnssTypeDef(_RequiredGnssTypeDef, _OptionalGnssTypeDef):
    pass


IpTypeDef = TypedDict(
    "IpTypeDef",
    {
        "IpAddress": str,
    },
)

WiFiAccessPointTypeDef = TypedDict(
    "WiFiAccessPointTypeDef",
    {
        "MacAddress": str,
        "Rss": int,
    },
)

GetPositionEstimateResponseTypeDef = TypedDict(
    "GetPositionEstimateResponseTypeDef",
    {
        "GeoJsonPayload": StreamingBody,
        "ResponseMetadata": "ResponseMetadataTypeDef",
    },
)

GetPositionRequestRequestTypeDef = TypedDict(
    "GetPositionRequestRequestTypeDef",
    {
        "ResourceIdentifier": str,
        "ResourceType": PositionResourceTypeType,
    },
)

_RequiredGetResourceEventConfigurationRequestRequestTypeDef = TypedDict(
    "_RequiredGetResourceEventConfigurationRequestRequestTypeDef",
    {
        "Identifier": str,
        "IdentifierType": IdentifierTypeType,
    },
)
_OptionalGetResourceEventConfigurationRequestRequestTypeDef = TypedDict(
    "_OptionalGetResourceEventConfigurationRequestRequestTypeDef",
    {
        "PartnerType": Literal["Sidewalk"],
    },
    total=False,
)


class GetResourceEventConfigurationRequestRequestTypeDef(
    _RequiredGetResourceEventConfigurationRequestRequestTypeDef,
    _OptionalGetResourceEventConfigurationRequestRequestTypeDef,
):
    pass


GetResourceLogLevelRequestRequestTypeDef = TypedDict(
    "GetResourceLogLevelRequestRequestTypeDef",
    {
        "ResourceIdentifier": str,
        "ResourceType": str,
    },
)

GetResourceLogLevelResponseTypeDef = TypedDict(
    "GetResourceLogLevelResponseTypeDef",
    {
        "LogLevel": LogLevelType,
        "ResponseMetadata": "ResponseMetadataTypeDef",
    },
)

GetResourcePositionRequestRequestTypeDef = TypedDict(
    "GetResourcePositionRequestRequestTypeDef",
    {
        "ResourceIdentifier": str,
        "ResourceType": PositionResourceTypeType,
    },
)

GetResourcePositionResponseTypeDef = TypedDict(
    "GetResourcePositionResponseTypeDef",
    {
        "GeoJsonPayload": StreamingBody,
        "ResponseMetadata": "ResponseMetadataTypeDef",
    },
)

GetServiceEndpointRequestRequestTypeDef = TypedDict(
    "GetServiceEndpointRequestRequestTypeDef",
    {
        "ServiceType": WirelessGatewayServiceTypeType,
    },
    total=False,
)

GetServiceEndpointResponseTypeDef = TypedDict(
    "GetServiceEndpointResponseTypeDef",
    {
        "ServiceType": WirelessGatewayServiceTypeType,
        "ServiceEndpoint": str,
        "ServerTrust": str,
        "ResponseMetadata": "ResponseMetadataTypeDef",
    },
)

GetServiceProfileRequestRequestTypeDef = TypedDict(
    "GetServiceProfileRequestRequestTypeDef",
    {
        "Id": str,
    },
)

LoRaWANGetServiceProfileInfoTypeDef = TypedDict(
    "LoRaWANGetServiceProfileInfoTypeDef",
    {
        "UlRate": int,
        "UlBucketSize": int,
        "UlRatePolicy": str,
        "DlRate": int,
        "DlBucketSize": int,
        "DlRatePolicy": str,
        "AddGwMetadata": bool,
        "DevStatusReqFreq": int,
        "ReportDevStatusBattery": bool,
        "ReportDevStatusMargin": bool,
        "DrMin": int,
        "DrMax": int,
        "ChannelMask": str,
        "PrAllowed": bool,
        "HrAllowed": bool,
        "RaAllowed": bool,
        "NwkGeoLoc": bool,
        "TargetPer": int,
        "MinGwDiversity": int,
    },
    total=False,
)

GetWirelessDeviceImportTaskRequestRequestTypeDef = TypedDict(
    "GetWirelessDeviceImportTaskRequestRequestTypeDef",
    {
        "Id": str,
    },
)

SidewalkGetStartImportInfoTypeDef = TypedDict(
    "SidewalkGetStartImportInfoTypeDef",
    {
        "DeviceCreationFileList": List[str],
        "Role": str,
    },
    total=False,
)

GetWirelessDeviceRequestRequestTypeDef = TypedDict(
    "GetWirelessDeviceRequestRequestTypeDef",
    {
        "Identifier": str,
        "IdentifierType": WirelessDeviceIdTypeType,
    },
)

GetWirelessDeviceStatisticsRequestRequestTypeDef = TypedDict(
    "GetWirelessDeviceStatisticsRequestRequestTypeDef",
    {
        "WirelessDeviceId": str,
    },
)

SidewalkDeviceMetadataTypeDef = TypedDict(
    "SidewalkDeviceMetadataTypeDef",
    {
        "Rssi": int,
        "BatteryLevel": BatteryLevelType,
        "Event": EventType,
        "DeviceState": DeviceStateType,
    },
    total=False,
)

GetWirelessGatewayCertificateRequestRequestTypeDef = TypedDict(
    "GetWirelessGatewayCertificateRequestRequestTypeDef",
    {
        "Id": str,
    },
)

GetWirelessGatewayCertificateResponseTypeDef = TypedDict(
    "GetWirelessGatewayCertificateResponseTypeDef",
    {
        "IotCertificateId": str,
        "LoRaWANNetworkServerCertificateId": str,
        "ResponseMetadata": "ResponseMetadataTypeDef",
    },
)

GetWirelessGatewayFirmwareInformationRequestRequestTypeDef = TypedDict(
    "GetWirelessGatewayFirmwareInformationRequestRequestTypeDef",
    {
        "Id": str,
    },
)

GetWirelessGatewayRequestRequestTypeDef = TypedDict(
    "GetWirelessGatewayRequestRequestTypeDef",
    {
        "Identifier": str,
        "IdentifierType": WirelessGatewayIdTypeType,
    },
)

GetWirelessGatewayStatisticsRequestRequestTypeDef = TypedDict(
    "GetWirelessGatewayStatisticsRequestRequestTypeDef",
    {
        "WirelessGatewayId": str,
    },
)

GetWirelessGatewayStatisticsResponseTypeDef = TypedDict(
    "GetWirelessGatewayStatisticsResponseTypeDef",
    {
        "WirelessGatewayId": str,
        "LastUplinkReceivedAt": str,
        "ConnectionStatus": ConnectionStatusType,
        "ResponseMetadata": "ResponseMetadataTypeDef",
    },
)

GetWirelessGatewayTaskDefinitionRequestRequestTypeDef = TypedDict(
    "GetWirelessGatewayTaskDefinitionRequestRequestTypeDef",
    {
        "Id": str,
    },
)

GetWirelessGatewayTaskRequestRequestTypeDef = TypedDict(
    "GetWirelessGatewayTaskRequestRequestTypeDef",
    {
        "Id": str,
    },
)

GetWirelessGatewayTaskResponseTypeDef = TypedDict(
    "GetWirelessGatewayTaskResponseTypeDef",
    {
        "WirelessGatewayId": str,
        "WirelessGatewayTaskDefinitionId": str,
        "LastUplinkReceivedAt": str,
        "TaskCreatedAt": str,
        "Status": WirelessGatewayTaskStatusType,
        "ResponseMetadata": "ResponseMetadataTypeDef",
    },
)

GlobalIdentityTypeDef = TypedDict(
    "GlobalIdentityTypeDef",
    {
        "Lac": int,
        "GeranCid": int,
    },
)

GsmLocalIdTypeDef = TypedDict(
    "GsmLocalIdTypeDef",
    {
        "Bsic": int,
        "Bcch": int,
    },
)

ImportedSidewalkDeviceTypeDef = TypedDict(
    "ImportedSidewalkDeviceTypeDef",
    {
        "SidewalkManufacturingSn": str,
        "OnboardingStatus": OnboardStatusType,
        "OnboardingStatusReason": str,
        "LastUpdateTime": datetime,
    },
    total=False,
)

LoRaWANJoinEventNotificationConfigurationsTypeDef = TypedDict(
    "LoRaWANJoinEventNotificationConfigurationsTypeDef",
    {
        "DevEuiEventTopic": EventNotificationTopicStatusType,
    },
    total=False,
)

LoRaWANJoinResourceTypeEventConfigurationTypeDef = TypedDict(
    "LoRaWANJoinResourceTypeEventConfigurationTypeDef",
    {
        "WirelessDeviceEventTopic": EventNotificationTopicStatusType,
    },
    total=False,
)

ListDestinationsRequestRequestTypeDef = TypedDict(
    "ListDestinationsRequestRequestTypeDef",
    {
        "MaxResults": int,
        "NextToken": str,
    },
    total=False,
)

ListDeviceProfilesRequestRequestTypeDef = TypedDict(
    "ListDeviceProfilesRequestRequestTypeDef",
    {
        "NextToken": str,
        "MaxResults": int,
        "DeviceProfileType": DeviceProfileTypeType,
    },
    total=False,
)

_RequiredListDevicesForWirelessDeviceImportTaskRequestRequestTypeDef = TypedDict(
    "_RequiredListDevicesForWirelessDeviceImportTaskRequestRequestTypeDef",
    {
        "Id": str,
    },
)
_OptionalListDevicesForWirelessDeviceImportTaskRequestRequestTypeDef = TypedDict(
    "_OptionalListDevicesForWirelessDeviceImportTaskRequestRequestTypeDef",
    {
        "MaxResults": int,
        "NextToken": str,
        "Status": OnboardStatusType,
    },
    total=False,
)


class ListDevicesForWirelessDeviceImportTaskRequestRequestTypeDef(
    _RequiredListDevicesForWirelessDeviceImportTaskRequestRequestTypeDef,
    _OptionalListDevicesForWirelessDeviceImportTaskRequestRequestTypeDef,
):
    pass


_RequiredListEventConfigurationsRequestRequestTypeDef = TypedDict(
    "_RequiredListEventConfigurationsRequestRequestTypeDef",
    {
        "ResourceType": EventNotificationResourceTypeType,
    },
)
_OptionalListEventConfigurationsRequestRequestTypeDef = TypedDict(
    "_OptionalListEventConfigurationsRequestRequestTypeDef",
    {
        "MaxResults": int,
        "NextToken": str,
    },
    total=False,
)


class ListEventConfigurationsRequestRequestTypeDef(
    _RequiredListEventConfigurationsRequestRequestTypeDef,
    _OptionalListEventConfigurationsRequestRequestTypeDef,
):
    pass


ListFuotaTasksRequestRequestTypeDef = TypedDict(
    "ListFuotaTasksRequestRequestTypeDef",
    {
        "NextToken": str,
        "MaxResults": int,
    },
    total=False,
)

_RequiredListMulticastGroupsByFuotaTaskRequestRequestTypeDef = TypedDict(
    "_RequiredListMulticastGroupsByFuotaTaskRequestRequestTypeDef",
    {
        "Id": str,
    },
)
_OptionalListMulticastGroupsByFuotaTaskRequestRequestTypeDef = TypedDict(
    "_OptionalListMulticastGroupsByFuotaTaskRequestRequestTypeDef",
    {
        "NextToken": str,
        "MaxResults": int,
    },
    total=False,
)


class ListMulticastGroupsByFuotaTaskRequestRequestTypeDef(
    _RequiredListMulticastGroupsByFuotaTaskRequestRequestTypeDef,
    _OptionalListMulticastGroupsByFuotaTaskRequestRequestTypeDef,
):
    pass


MulticastGroupByFuotaTaskTypeDef = TypedDict(
    "MulticastGroupByFuotaTaskTypeDef",
    {
        "Id": str,
    },
    total=False,
)

ListMulticastGroupsRequestRequestTypeDef = TypedDict(
    "ListMulticastGroupsRequestRequestTypeDef",
    {
        "NextToken": str,
        "MaxResults": int,
    },
    total=False,
)

MulticastGroupTypeDef = TypedDict(
    "MulticastGroupTypeDef",
    {
        "Id": str,
        "Arn": str,
        "Name": str,
    },
    total=False,
)

ListNetworkAnalyzerConfigurationsRequestRequestTypeDef = TypedDict(
    "ListNetworkAnalyzerConfigurationsRequestRequestTypeDef",
    {
        "MaxResults": int,
        "NextToken": str,
    },
    total=False,
)

NetworkAnalyzerConfigurationsTypeDef = TypedDict(
    "NetworkAnalyzerConfigurationsTypeDef",
    {
        "Arn": str,
        "Name": str,
    },
    total=False,
)

ListPartnerAccountsRequestRequestTypeDef = TypedDict(
    "ListPartnerAccountsRequestRequestTypeDef",
    {
        "NextToken": str,
        "MaxResults": int,
    },
    total=False,
)

ListPositionConfigurationsRequestRequestTypeDef = TypedDict(
    "ListPositionConfigurationsRequestRequestTypeDef",
    {
        "ResourceType": PositionResourceTypeType,
        "MaxResults": int,
        "NextToken": str,
    },
    total=False,
)

_RequiredListQueuedMessagesRequestRequestTypeDef = TypedDict(
    "_RequiredListQueuedMessagesRequestRequestTypeDef",
    {
        "Id": str,
    },
)
_OptionalListQueuedMessagesRequestRequestTypeDef = TypedDict(
    "_OptionalListQueuedMessagesRequestRequestTypeDef",
    {
        "NextToken": str,
        "MaxResults": int,
        "WirelessDeviceType": WirelessDeviceTypeType,
    },
    total=False,
)


class ListQueuedMessagesRequestRequestTypeDef(
    _RequiredListQueuedMessagesRequestRequestTypeDef,
    _OptionalListQueuedMessagesRequestRequestTypeDef,
):
    pass


ListServiceProfilesRequestRequestTypeDef = TypedDict(
    "ListServiceProfilesRequestRequestTypeDef",
    {
        "NextToken": str,
        "MaxResults": int,
    },
    total=False,
)

ServiceProfileTypeDef = TypedDict(
    "ServiceProfileTypeDef",
    {
        "Arn": str,
        "Name": str,
        "Id": str,
    },
    total=False,
)

ListTagsForResourceRequestRequestTypeDef = TypedDict(
    "ListTagsForResourceRequestRequestTypeDef",
    {
        "ResourceArn": str,
    },
)

ListWirelessDeviceImportTasksRequestRequestTypeDef = TypedDict(
    "ListWirelessDeviceImportTasksRequestRequestTypeDef",
    {
        "MaxResults": int,
        "NextToken": str,
    },
    total=False,
)

ListWirelessDevicesRequestRequestTypeDef = TypedDict(
    "ListWirelessDevicesRequestRequestTypeDef",
    {
        "MaxResults": int,
        "NextToken": str,
        "DestinationName": str,
        "DeviceProfileId": str,
        "ServiceProfileId": str,
        "WirelessDeviceType": WirelessDeviceTypeType,
        "FuotaTaskId": str,
        "MulticastGroupId": str,
    },
    total=False,
)

ListWirelessGatewayTaskDefinitionsRequestRequestTypeDef = TypedDict(
    "ListWirelessGatewayTaskDefinitionsRequestRequestTypeDef",
    {
        "MaxResults": int,
        "NextToken": str,
        "TaskDefinitionType": Literal["UPDATE"],
    },
    total=False,
)

ListWirelessGatewaysRequestRequestTypeDef = TypedDict(
    "ListWirelessGatewaysRequestRequestTypeDef",
    {
        "NextToken": str,
        "MaxResults": int,
    },
    total=False,
)

LoRaWANGatewayMetadataTypeDef = TypedDict(
    "LoRaWANGatewayMetadataTypeDef",
    {
        "GatewayEui": str,
        "Snr": float,
        "Rssi": float,
    },
    total=False,
)

OtaaV10XTypeDef = TypedDict(
    "OtaaV10XTypeDef",
    {
        "AppKey": str,
        "AppEui": str,
        "GenAppKey": str,
    },
    total=False,
)

OtaaV11TypeDef = TypedDict(
    "OtaaV11TypeDef",
    {
        "AppKey": str,
        "NwkKey": str,
        "JoinEui": str,
    },
    total=False,
)

LoRaWANGatewayVersionTypeDef = TypedDict(
    "LoRaWANGatewayVersionTypeDef",
    {
        "PackageVersion": str,
        "Model": str,
        "Station": str,
    },
    total=False,
)

LoRaWANListDeviceTypeDef = TypedDict(
    "LoRaWANListDeviceTypeDef",
    {
        "DevEui": str,
    },
    total=False,
)

LoRaWANMulticastMetadataTypeDef = TypedDict(
    "LoRaWANMulticastMetadataTypeDef",
    {
        "FPort": int,
    },
    total=False,
)

LoRaWANStartFuotaTaskTypeDef = TypedDict(
    "LoRaWANStartFuotaTaskTypeDef",
    {
        "StartTime": Union[datetime, str],
    },
    total=False,
)

UpdateAbpV10XTypeDef = TypedDict(
    "UpdateAbpV10XTypeDef",
    {
        "FCntStart": int,
    },
    total=False,
)

UpdateAbpV11TypeDef = TypedDict(
    "UpdateAbpV11TypeDef",
    {
        "FCntStart": int,
    },
    total=False,
)

LteLocalIdTypeDef = TypedDict(
    "LteLocalIdTypeDef",
    {
        "Pci": int,
        "Earfcn": int,
    },
)

_RequiredLteNmrObjTypeDef = TypedDict(
    "_RequiredLteNmrObjTypeDef",
    {
        "Pci": int,
        "Earfcn": int,
        "EutranCid": int,
    },
)
_OptionalLteNmrObjTypeDef = TypedDict(
    "_OptionalLteNmrObjTypeDef",
    {
        "Rsrp": int,
        "Rsrq": float,
    },
    total=False,
)


class LteNmrObjTypeDef(_RequiredLteNmrObjTypeDef, _OptionalLteNmrObjTypeDef):
    pass


SemtechGnssConfigurationTypeDef = TypedDict(
    "SemtechGnssConfigurationTypeDef",
    {
        "Status": PositionConfigurationStatusType,
        "Fec": PositionConfigurationFecType,
    },
)

SemtechGnssDetailTypeDef = TypedDict(
    "SemtechGnssDetailTypeDef",
    {
        "Provider": Literal["Semtech"],
        "Type": Literal["GNSS"],
        "Status": PositionConfigurationStatusType,
        "Fec": PositionConfigurationFecType,
    },
    total=False,
)

PutResourceLogLevelRequestRequestTypeDef = TypedDict(
    "PutResourceLogLevelRequestRequestTypeDef",
    {
        "ResourceIdentifier": str,
        "ResourceType": str,
        "LogLevel": LogLevelType,
    },
)

ResetResourceLogLevelRequestRequestTypeDef = TypedDict(
    "ResetResourceLogLevelRequestRequestTypeDef",
    {
        "ResourceIdentifier": str,
        "ResourceType": str,
    },
)

ResponseMetadataTypeDef = TypedDict(
    "ResponseMetadataTypeDef",
    {
        "RequestId": str,
        "HostId": str,
        "HTTPStatusCode": int,
        "HTTPHeaders": Dict[str, str],
        "RetryAttempts": int,
    },
)

SendDataToMulticastGroupResponseTypeDef = TypedDict(
    "SendDataToMulticastGroupResponseTypeDef",
    {
        "MessageId": str,
        "ResponseMetadata": "ResponseMetadataTypeDef",
    },
)

SendDataToWirelessDeviceResponseTypeDef = TypedDict(
    "SendDataToWirelessDeviceResponseTypeDef",
    {
        "MessageId": str,
        "ResponseMetadata": "ResponseMetadataTypeDef",
    },
)

SidewalkSendDataToDeviceTypeDef = TypedDict(
    "SidewalkSendDataToDeviceTypeDef",
    {
        "Seq": int,
        "MessageType": MessageTypeType,
        "AckModeRetryDurationSecs": int,
    },
    total=False,
)

SidewalkSingleStartImportInfoTypeDef = TypedDict(
    "SidewalkSingleStartImportInfoTypeDef",
    {
        "SidewalkManufacturingSn": str,
    },
    total=False,
)

SidewalkStartImportInfoTypeDef = TypedDict(
    "SidewalkStartImportInfoTypeDef",
    {
        "DeviceCreationFile": str,
        "Role": str,
    },
    total=False,
)

SidewalkUpdateAccountTypeDef = TypedDict(
    "SidewalkUpdateAccountTypeDef",
    {
        "AppServerPrivateKey": str,
    },
    total=False,
)

SidewalkUpdateImportInfoTypeDef = TypedDict(
    "SidewalkUpdateImportInfoTypeDef",
    {
        "DeviceCreationFile": str,
    },
    total=False,
)

StartSingleWirelessDeviceImportTaskResponseTypeDef = TypedDict(
    "StartSingleWirelessDeviceImportTaskResponseTypeDef",
    {
        "Id": str,
        "Arn": str,
        "ResponseMetadata": "ResponseMetadataTypeDef",
    },
)

StartWirelessDeviceImportTaskResponseTypeDef = TypedDict(
    "StartWirelessDeviceImportTaskResponseTypeDef",
    {
        "Id": str,
        "Arn": str,
        "ResponseMetadata": "ResponseMetadataTypeDef",
    },
)

TdscdmaLocalIdTypeDef = TypedDict(
    "TdscdmaLocalIdTypeDef",
    {
        "Uarfcn": int,
        "CellParams": int,
    },
)

_RequiredTdscdmaNmrObjTypeDef = TypedDict(
    "_RequiredTdscdmaNmrObjTypeDef",
    {
        "Uarfcn": int,
        "CellParams": int,
    },
)
_OptionalTdscdmaNmrObjTypeDef = TypedDict(
    "_OptionalTdscdmaNmrObjTypeDef",
    {
        "UtranCid": int,
        "Rscp": int,
        "PathLoss": int,
    },
    total=False,
)


class TdscdmaNmrObjTypeDef(_RequiredTdscdmaNmrObjTypeDef, _OptionalTdscdmaNmrObjTypeDef):
    pass


TestWirelessDeviceRequestRequestTypeDef = TypedDict(
    "TestWirelessDeviceRequestRequestTypeDef",
    {
        "Id": str,
    },
)

TestWirelessDeviceResponseTypeDef = TypedDict(
    "TestWirelessDeviceResponseTypeDef",
    {
        "Result": str,
        "ResponseMetadata": "ResponseMetadataTypeDef",
    },
)

UntagResourceRequestRequestTypeDef = TypedDict(
    "UntagResourceRequestRequestTypeDef",
    {
        "ResourceArn": str,
        "TagKeys": Sequence[str],
    },
)

_RequiredUpdateDestinationRequestRequestTypeDef = TypedDict(
    "_RequiredUpdateDestinationRequestRequestTypeDef",
    {
        "Name": str,
    },
)
_OptionalUpdateDestinationRequestRequestTypeDef = TypedDict(
    "_OptionalUpdateDestinationRequestRequestTypeDef",
    {
        "ExpressionType": ExpressionTypeType,
        "Expression": str,
        "Description": str,
        "RoleArn": str,
    },
    total=False,
)


class UpdateDestinationRequestRequestTypeDef(
    _RequiredUpdateDestinationRequestRequestTypeDef, _OptionalUpdateDestinationRequestRequestTypeDef
):
    pass


UpdatePositionRequestRequestTypeDef = TypedDict(
    "UpdatePositionRequestRequestTypeDef",
    {
        "ResourceIdentifier": str,
        "ResourceType": PositionResourceTypeType,
        "Position": Sequence[float],
    },
)

_RequiredUpdateResourcePositionRequestRequestTypeDef = TypedDict(
    "_RequiredUpdateResourcePositionRequestRequestTypeDef",
    {
        "ResourceIdentifier": str,
        "ResourceType": PositionResourceTypeType,
    },
)
_OptionalUpdateResourcePositionRequestRequestTypeDef = TypedDict(
    "_OptionalUpdateResourcePositionRequestRequestTypeDef",
    {
        "GeoJsonPayload": Union[str, bytes, IO[Any], StreamingBody],
    },
    total=False,
)


class UpdateResourcePositionRequestRequestTypeDef(
    _RequiredUpdateResourcePositionRequestRequestTypeDef,
    _OptionalUpdateResourcePositionRequestRequestTypeDef,
):
    pass


_RequiredUpdateWirelessGatewayRequestRequestTypeDef = TypedDict(
    "_RequiredUpdateWirelessGatewayRequestRequestTypeDef",
    {
        "Id": str,
    },
)
_OptionalUpdateWirelessGatewayRequestRequestTypeDef = TypedDict(
    "_OptionalUpdateWirelessGatewayRequestRequestTypeDef",
    {
        "Name": str,
        "Description": str,
        "JoinEuiFilters": Sequence[Sequence[str]],
        "NetIdFilters": Sequence[str],
        "MaxEirp": float,
    },
    total=False,
)


class UpdateWirelessGatewayRequestRequestTypeDef(
    _RequiredUpdateWirelessGatewayRequestRequestTypeDef,
    _OptionalUpdateWirelessGatewayRequestRequestTypeDef,
):
    pass


WcdmaLocalIdTypeDef = TypedDict(
    "WcdmaLocalIdTypeDef",
    {
        "Uarfcndl": int,
        "Psc": int,
    },
)

_RequiredWcdmaNmrObjTypeDef = TypedDict(
    "_RequiredWcdmaNmrObjTypeDef",
    {
        "Uarfcndl": int,
        "Psc": int,
        "UtranCid": int,
    },
)
_OptionalWcdmaNmrObjTypeDef = TypedDict(
    "_OptionalWcdmaNmrObjTypeDef",
    {
        "Rscp": int,
        "PathLoss": int,
    },
    total=False,
)


class WcdmaNmrObjTypeDef(_RequiredWcdmaNmrObjTypeDef, _OptionalWcdmaNmrObjTypeDef):
    pass


WirelessDeviceEventLogOptionTypeDef = TypedDict(
    "WirelessDeviceEventLogOptionTypeDef",
    {
        "Event": WirelessDeviceEventType,
        "LogLevel": LogLevelType,
    },
)

WirelessGatewayEventLogOptionTypeDef = TypedDict(
    "WirelessGatewayEventLogOptionTypeDef",
    {
        "Event": WirelessGatewayEventType,
        "LogLevel": LogLevelType,
    },
)

AbpV10XTypeDef = TypedDict(
    "AbpV10XTypeDef",
    {
        "DevAddr": str,
        "SessionKeys": SessionKeysAbpV10XTypeDef,
        "FCntStart": int,
    },
    total=False,
)

AbpV11TypeDef = TypedDict(
    "AbpV11TypeDef",
    {
        "DevAddr": str,
        "SessionKeys": SessionKeysAbpV11TypeDef,
        "FCntStart": int,
    },
    total=False,
)

GetPositionResponseTypeDef = TypedDict(
    "GetPositionResponseTypeDef",
    {
        "Position": List[float],
        "Accuracy": AccuracyTypeDef,
        "SolverType": Literal["GNSS"],
        "SolverProvider": Literal["Semtech"],
        "SolverVersion": str,
        "Timestamp": str,
        "ResponseMetadata": "ResponseMetadataTypeDef",
    },
)

AssociateAwsAccountWithPartnerAccountResponseTypeDef = TypedDict(
    "AssociateAwsAccountWithPartnerAccountResponseTypeDef",
    {
        "Sidewalk": SidewalkAccountInfoTypeDef,
        "Arn": str,
        "ResponseMetadata": "ResponseMetadataTypeDef",
    },
)

_RequiredAssociateAwsAccountWithPartnerAccountRequestRequestTypeDef = TypedDict(
    "_RequiredAssociateAwsAccountWithPartnerAccountRequestRequestTypeDef",
    {
        "Sidewalk": SidewalkAccountInfoTypeDef,
    },
)
_OptionalAssociateAwsAccountWithPartnerAccountRequestRequestTypeDef = TypedDict(
    "_OptionalAssociateAwsAccountWithPartnerAccountRequestRequestTypeDef",
    {
        "ClientRequestToken": str,
        "Tags": Sequence[TagTypeDef],
    },
    total=False,
)


class AssociateAwsAccountWithPartnerAccountRequestRequestTypeDef(
    _RequiredAssociateAwsAccountWithPartnerAccountRequestRequestTypeDef,
    _OptionalAssociateAwsAccountWithPartnerAccountRequestRequestTypeDef,
):
    pass


_RequiredCreateDestinationRequestRequestTypeDef = TypedDict(
    "_RequiredCreateDestinationRequestRequestTypeDef",
    {
        "Name": str,
        "ExpressionType": ExpressionTypeType,
        "Expression": str,
        "RoleArn": str,
    },
)
_OptionalCreateDestinationRequestRequestTypeDef = TypedDict(
    "_OptionalCreateDestinationRequestRequestTypeDef",
    {
        "Description": str,
        "Tags": Sequence[TagTypeDef],
        "ClientRequestToken": str,
    },
    total=False,
)


class CreateDestinationRequestRequestTypeDef(
    _RequiredCreateDestinationRequestRequestTypeDef, _OptionalCreateDestinationRequestRequestTypeDef
):
    pass


ListTagsForResourceResponseTypeDef = TypedDict(
    "ListTagsForResourceResponseTypeDef",
    {
        "Tags": List[TagTypeDef],
        "ResponseMetadata": "ResponseMetadataTypeDef",
    },
)

_RequiredStartBulkAssociateWirelessDeviceWithMulticastGroupRequestRequestTypeDef = TypedDict(
    "_RequiredStartBulkAssociateWirelessDeviceWithMulticastGroupRequestRequestTypeDef",
    {
        "Id": str,
    },
)
_OptionalStartBulkAssociateWirelessDeviceWithMulticastGroupRequestRequestTypeDef = TypedDict(
    "_OptionalStartBulkAssociateWirelessDeviceWithMulticastGroupRequestRequestTypeDef",
    {
        "QueryString": str,
        "Tags": Sequence[TagTypeDef],
    },
    total=False,
)


class StartBulkAssociateWirelessDeviceWithMulticastGroupRequestRequestTypeDef(
    _RequiredStartBulkAssociateWirelessDeviceWithMulticastGroupRequestRequestTypeDef,
    _OptionalStartBulkAssociateWirelessDeviceWithMulticastGroupRequestRequestTypeDef,
):
    pass


_RequiredStartBulkDisassociateWirelessDeviceFromMulticastGroupRequestRequestTypeDef = TypedDict(
    "_RequiredStartBulkDisassociateWirelessDeviceFromMulticastGroupRequestRequestTypeDef",
    {
        "Id": str,
    },
)
_OptionalStartBulkDisassociateWirelessDeviceFromMulticastGroupRequestRequestTypeDef = TypedDict(
    "_OptionalStartBulkDisassociateWirelessDeviceFromMulticastGroupRequestRequestTypeDef",
    {
        "QueryString": str,
        "Tags": Sequence[TagTypeDef],
    },
    total=False,
)


class StartBulkDisassociateWirelessDeviceFromMulticastGroupRequestRequestTypeDef(
    _RequiredStartBulkDisassociateWirelessDeviceFromMulticastGroupRequestRequestTypeDef,
    _OptionalStartBulkDisassociateWirelessDeviceFromMulticastGroupRequestRequestTypeDef,
):
    pass


TagResourceRequestRequestTypeDef = TypedDict(
    "TagResourceRequestRequestTypeDef",
    {
        "ResourceArn": str,
        "Tags": Sequence[TagTypeDef],
    },
)

LoRaWANGatewayTypeDef = TypedDict(
    "LoRaWANGatewayTypeDef",
    {
        "GatewayEui": str,
        "RfRegion": str,
        "JoinEuiFilters": Sequence[Sequence[str]],
        "NetIdFilters": Sequence[str],
        "SubBands": Sequence[int],
        "Beaconing": BeaconingTypeDef,
        "MaxEirp": float,
    },
    total=False,
)

_RequiredCdmaObjTypeDef = TypedDict(
    "_RequiredCdmaObjTypeDef",
    {
        "SystemId": int,
        "NetworkId": int,
        "BaseStationId": int,
    },
)
_OptionalCdmaObjTypeDef = TypedDict(
    "_OptionalCdmaObjTypeDef",
    {
        "RegistrationZone": int,
        "CdmaLocalId": CdmaLocalIdTypeDef,
        "PilotPower": int,
        "BaseLat": float,
        "BaseLng": float,
        "CdmaNmr": Sequence[CdmaNmrObjTypeDef],
    },
    total=False,
)


class CdmaObjTypeDef(_RequiredCdmaObjTypeDef, _OptionalCdmaObjTypeDef):
    pass


SidewalkDeviceTypeDef = TypedDict(
    "SidewalkDeviceTypeDef",
    {
        "AmazonId": str,
        "SidewalkId": str,
        "SidewalkManufacturingSn": str,
        "DeviceCertificates": List[CertificateListTypeDef],
        "PrivateKeys": List[CertificateListTypeDef],
        "DeviceProfileId": str,
        "CertificateId": str,
        "Status": WirelessDeviceSidewalkStatusType,
    },
    total=False,
)

SidewalkListDeviceTypeDef = TypedDict(
    "SidewalkListDeviceTypeDef",
    {
        "AmazonId": str,
        "SidewalkId": str,
        "SidewalkManufacturingSn": str,
        "DeviceCertificates": List[CertificateListTypeDef],
        "DeviceProfileId": str,
        "Status": WirelessDeviceSidewalkStatusType,
    },
    total=False,
)

ConnectionStatusEventConfigurationTypeDef = TypedDict(
    "ConnectionStatusEventConfigurationTypeDef",
    {
        "LoRaWAN": LoRaWANConnectionStatusEventNotificationConfigurationsTypeDef,
        "WirelessGatewayIdEventTopic": EventNotificationTopicStatusType,
    },
    total=False,
)

ConnectionStatusResourceTypeEventConfigurationTypeDef = TypedDict(
    "ConnectionStatusResourceTypeEventConfigurationTypeDef",
    {
        "LoRaWAN": LoRaWANConnectionStatusResourceTypeEventConfigurationTypeDef,
    },
    total=False,
)

CreateDeviceProfileRequestRequestTypeDef = TypedDict(
    "CreateDeviceProfileRequestRequestTypeDef",
    {
        "Name": str,
        "LoRaWAN": LoRaWANDeviceProfileTypeDef,
        "Tags": Sequence[TagTypeDef],
        "ClientRequestToken": str,
        "Sidewalk": Mapping[str, Any],
    },
    total=False,
)

_RequiredCreateFuotaTaskRequestRequestTypeDef = TypedDict(
    "_RequiredCreateFuotaTaskRequestRequestTypeDef",
    {
        "FirmwareUpdateImage": str,
        "FirmwareUpdateRole": str,
    },
)
_OptionalCreateFuotaTaskRequestRequestTypeDef = TypedDict(
    "_OptionalCreateFuotaTaskRequestRequestTypeDef",
    {
        "Name": str,
        "Description": str,
        "ClientRequestToken": str,
        "LoRaWAN": LoRaWANFuotaTaskTypeDef,
        "Tags": Sequence[TagTypeDef],
        "RedundancyPercent": int,
        "FragmentSizeBytes": int,
        "FragmentIntervalMS": int,
    },
    total=False,
)


class CreateFuotaTaskRequestRequestTypeDef(
    _RequiredCreateFuotaTaskRequestRequestTypeDef, _OptionalCreateFuotaTaskRequestRequestTypeDef
):
    pass


_RequiredUpdateFuotaTaskRequestRequestTypeDef = TypedDict(
    "_RequiredUpdateFuotaTaskRequestRequestTypeDef",
    {
        "Id": str,
    },
)
_OptionalUpdateFuotaTaskRequestRequestTypeDef = TypedDict(
    "_OptionalUpdateFuotaTaskRequestRequestTypeDef",
    {
        "Name": str,
        "Description": str,
        "LoRaWAN": LoRaWANFuotaTaskTypeDef,
        "FirmwareUpdateImage": str,
        "FirmwareUpdateRole": str,
        "RedundancyPercent": int,
        "FragmentSizeBytes": int,
        "FragmentIntervalMS": int,
    },
    total=False,
)


class UpdateFuotaTaskRequestRequestTypeDef(
    _RequiredUpdateFuotaTaskRequestRequestTypeDef, _OptionalUpdateFuotaTaskRequestRequestTypeDef
):
    pass


_RequiredCreateMulticastGroupRequestRequestTypeDef = TypedDict(
    "_RequiredCreateMulticastGroupRequestRequestTypeDef",
    {
        "LoRaWAN": LoRaWANMulticastTypeDef,
    },
)
_OptionalCreateMulticastGroupRequestRequestTypeDef = TypedDict(
    "_OptionalCreateMulticastGroupRequestRequestTypeDef",
    {
        "Name": str,
        "Description": str,
        "ClientRequestToken": str,
        "Tags": Sequence[TagTypeDef],
    },
    total=False,
)


class CreateMulticastGroupRequestRequestTypeDef(
    _RequiredCreateMulticastGroupRequestRequestTypeDef,
    _OptionalCreateMulticastGroupRequestRequestTypeDef,
):
    pass


_RequiredUpdateMulticastGroupRequestRequestTypeDef = TypedDict(
    "_RequiredUpdateMulticastGroupRequestRequestTypeDef",
    {
        "Id": str,
    },
)
_OptionalUpdateMulticastGroupRequestRequestTypeDef = TypedDict(
    "_OptionalUpdateMulticastGroupRequestRequestTypeDef",
    {
        "Name": str,
        "Description": str,
        "LoRaWAN": LoRaWANMulticastTypeDef,
    },
    total=False,
)


class UpdateMulticastGroupRequestRequestTypeDef(
    _RequiredUpdateMulticastGroupRequestRequestTypeDef,
    _OptionalUpdateMulticastGroupRequestRequestTypeDef,
):
    pass


_RequiredCreateNetworkAnalyzerConfigurationRequestRequestTypeDef = TypedDict(
    "_RequiredCreateNetworkAnalyzerConfigurationRequestRequestTypeDef",
    {
        "Name": str,
    },
)
_OptionalCreateNetworkAnalyzerConfigurationRequestRequestTypeDef = TypedDict(
    "_OptionalCreateNetworkAnalyzerConfigurationRequestRequestTypeDef",
    {
        "TraceContent": TraceContentTypeDef,
        "WirelessDevices": Sequence[str],
        "WirelessGateways": Sequence[str],
        "Description": str,
        "Tags": Sequence[TagTypeDef],
        "ClientRequestToken": str,
        "MulticastGroups": Sequence[str],
    },
    total=False,
)


class CreateNetworkAnalyzerConfigurationRequestRequestTypeDef(
    _RequiredCreateNetworkAnalyzerConfigurationRequestRequestTypeDef,
    _OptionalCreateNetworkAnalyzerConfigurationRequestRequestTypeDef,
):
    pass


GetNetworkAnalyzerConfigurationResponseTypeDef = TypedDict(
    "GetNetworkAnalyzerConfigurationResponseTypeDef",
    {
        "TraceContent": TraceContentTypeDef,
        "WirelessDevices": List[str],
        "WirelessGateways": List[str],
        "Description": str,
        "Arn": str,
        "Name": str,
        "MulticastGroups": List[str],
        "ResponseMetadata": "ResponseMetadataTypeDef",
    },
)

_RequiredUpdateNetworkAnalyzerConfigurationRequestRequestTypeDef = TypedDict(
    "_RequiredUpdateNetworkAnalyzerConfigurationRequestRequestTypeDef",
    {
        "ConfigurationName": str,
    },
)
_OptionalUpdateNetworkAnalyzerConfigurationRequestRequestTypeDef = TypedDict(
    "_OptionalUpdateNetworkAnalyzerConfigurationRequestRequestTypeDef",
    {
        "TraceContent": TraceContentTypeDef,
        "WirelessDevicesToAdd": Sequence[str],
        "WirelessDevicesToRemove": Sequence[str],
        "WirelessGatewaysToAdd": Sequence[str],
        "WirelessGatewaysToRemove": Sequence[str],
        "Description": str,
        "MulticastGroupsToAdd": Sequence[str],
        "MulticastGroupsToRemove": Sequence[str],
    },
    total=False,
)


class UpdateNetworkAnalyzerConfigurationRequestRequestTypeDef(
    _RequiredUpdateNetworkAnalyzerConfigurationRequestRequestTypeDef,
    _OptionalUpdateNetworkAnalyzerConfigurationRequestRequestTypeDef,
):
    pass


CreateServiceProfileRequestRequestTypeDef = TypedDict(
    "CreateServiceProfileRequestRequestTypeDef",
    {
        "Name": str,
        "LoRaWAN": LoRaWANServiceProfileTypeDef,
        "Tags": Sequence[TagTypeDef],
        "ClientRequestToken": str,
    },
    total=False,
)

SidewalkGetDeviceProfileTypeDef = TypedDict(
    "SidewalkGetDeviceProfileTypeDef",
    {
        "ApplicationServerPublicKey": str,
        "QualificationStatus": bool,
        "DakCertificateMetadata": List[DakCertificateMetadataTypeDef],
    },
    total=False,
)

ListDestinationsResponseTypeDef = TypedDict(
    "ListDestinationsResponseTypeDef",
    {
        "NextToken": str,
        "DestinationList": List[DestinationsTypeDef],
        "ResponseMetadata": "ResponseMetadataTypeDef",
    },
)

ListDeviceProfilesResponseTypeDef = TypedDict(
    "ListDeviceProfilesResponseTypeDef",
    {
        "NextToken": str,
        "DeviceProfileList": List[DeviceProfileTypeDef],
        "ResponseMetadata": "ResponseMetadataTypeDef",
    },
)

DeviceRegistrationStateEventConfigurationTypeDef = TypedDict(
    "DeviceRegistrationStateEventConfigurationTypeDef",
    {
        "Sidewalk": SidewalkEventNotificationConfigurationsTypeDef,
        "WirelessDeviceIdEventTopic": EventNotificationTopicStatusType,
    },
    total=False,
)

MessageDeliveryStatusEventConfigurationTypeDef = TypedDict(
    "MessageDeliveryStatusEventConfigurationTypeDef",
    {
        "Sidewalk": SidewalkEventNotificationConfigurationsTypeDef,
        "WirelessDeviceIdEventTopic": EventNotificationTopicStatusType,
    },
    total=False,
)

ProximityEventConfigurationTypeDef = TypedDict(
    "ProximityEventConfigurationTypeDef",
    {
        "Sidewalk": SidewalkEventNotificationConfigurationsTypeDef,
        "WirelessDeviceIdEventTopic": EventNotificationTopicStatusType,
    },
    total=False,
)

DeviceRegistrationStateResourceTypeEventConfigurationTypeDef = TypedDict(
    "DeviceRegistrationStateResourceTypeEventConfigurationTypeDef",
    {
        "Sidewalk": SidewalkResourceTypeEventConfigurationTypeDef,
    },
    total=False,
)

MessageDeliveryStatusResourceTypeEventConfigurationTypeDef = TypedDict(
    "MessageDeliveryStatusResourceTypeEventConfigurationTypeDef",
    {
        "Sidewalk": SidewalkResourceTypeEventConfigurationTypeDef,
    },
    total=False,
)

ProximityResourceTypeEventConfigurationTypeDef = TypedDict(
    "ProximityResourceTypeEventConfigurationTypeDef",
    {
        "Sidewalk": SidewalkResourceTypeEventConfigurationTypeDef,
    },
    total=False,
)

FPortsTypeDef = TypedDict(
    "FPortsTypeDef",
    {
        "Fuota": int,
        "Multicast": int,
        "ClockSync": int,
        "Positioning": PositioningTypeDef,
        "Applications": Sequence[ApplicationConfigTypeDef],
    },
    total=False,
)

UpdateFPortsTypeDef = TypedDict(
    "UpdateFPortsTypeDef",
    {
        "Positioning": PositioningTypeDef,
        "Applications": Sequence[ApplicationConfigTypeDef],
    },
    total=False,
)

ListFuotaTasksResponseTypeDef = TypedDict(
    "ListFuotaTasksResponseTypeDef",
    {
        "NextToken": str,
        "FuotaTaskList": List[FuotaTaskTypeDef],
        "ResponseMetadata": "ResponseMetadataTypeDef",
    },
)

ParticipatingGatewaysTypeDef = TypedDict(
    "ParticipatingGatewaysTypeDef",
    {
        "DownlinkMode": DownlinkModeType,
        "GatewayList": List[GatewayListItemTypeDef],
        "TransmissionInterval": int,
    },
)

GetFuotaTaskResponseTypeDef = TypedDict(
    "GetFuotaTaskResponseTypeDef",
    {
        "Arn": str,
        "Id": str,
        "Status": FuotaTaskStatusType,
        "Name": str,
        "Description": str,
        "LoRaWAN": LoRaWANFuotaTaskGetInfoTypeDef,
        "FirmwareUpdateImage": str,
        "FirmwareUpdateRole": str,
        "CreatedAt": datetime,
        "RedundancyPercent": int,
        "FragmentSizeBytes": int,
        "FragmentIntervalMS": int,
        "ResponseMetadata": "ResponseMetadataTypeDef",
    },
)

GetMulticastGroupResponseTypeDef = TypedDict(
    "GetMulticastGroupResponseTypeDef",
    {
        "Arn": str,
        "Id": str,
        "Name": str,
        "Description": str,
        "Status": str,
        "LoRaWAN": LoRaWANMulticastGetTypeDef,
        "CreatedAt": datetime,
        "ResponseMetadata": "ResponseMetadataTypeDef",
    },
)

GetMulticastGroupSessionResponseTypeDef = TypedDict(
    "GetMulticastGroupSessionResponseTypeDef",
    {
        "LoRaWAN": LoRaWANMulticastSessionTypeDef,
        "ResponseMetadata": "ResponseMetadataTypeDef",
    },
)

StartMulticastGroupSessionRequestRequestTypeDef = TypedDict(
    "StartMulticastGroupSessionRequestRequestTypeDef",
    {
        "Id": str,
        "LoRaWAN": LoRaWANMulticastSessionTypeDef,
    },
)

GetPartnerAccountResponseTypeDef = TypedDict(
    "GetPartnerAccountResponseTypeDef",
    {
        "Sidewalk": SidewalkAccountInfoWithFingerprintTypeDef,
        "AccountLinked": bool,
        "ResponseMetadata": "ResponseMetadataTypeDef",
    },
)

ListPartnerAccountsResponseTypeDef = TypedDict(
    "ListPartnerAccountsResponseTypeDef",
    {
        "NextToken": str,
        "Sidewalk": List[SidewalkAccountInfoWithFingerprintTypeDef],
        "ResponseMetadata": "ResponseMetadataTypeDef",
    },
)

GetServiceProfileResponseTypeDef = TypedDict(
    "GetServiceProfileResponseTypeDef",
    {
        "Arn": str,
        "Name": str,
        "Id": str,
        "LoRaWAN": LoRaWANGetServiceProfileInfoTypeDef,
        "ResponseMetadata": "ResponseMetadataTypeDef",
    },
)

GetWirelessDeviceImportTaskResponseTypeDef = TypedDict(
    "GetWirelessDeviceImportTaskResponseTypeDef",
    {
        "Id": str,
        "Arn": str,
        "DestinationName": str,
        "Sidewalk": SidewalkGetStartImportInfoTypeDef,
        "CreationTime": datetime,
        "Status": ImportTaskStatusType,
        "StatusReason": str,
        "InitializedImportedDeviceCount": int,
        "PendingImportedDeviceCount": int,
        "OnboardedImportedDeviceCount": int,
        "FailedImportedDeviceCount": int,
        "ResponseMetadata": "ResponseMetadataTypeDef",
    },
)

WirelessDeviceImportTaskTypeDef = TypedDict(
    "WirelessDeviceImportTaskTypeDef",
    {
        "Id": str,
        "Arn": str,
        "DestinationName": str,
        "Sidewalk": SidewalkGetStartImportInfoTypeDef,
        "CreationTime": datetime,
        "Status": ImportTaskStatusType,
        "StatusReason": str,
        "InitializedImportedDeviceCount": int,
        "PendingImportedDeviceCount": int,
        "OnboardedImportedDeviceCount": int,
        "FailedImportedDeviceCount": int,
    },
    total=False,
)

_RequiredGsmNmrObjTypeDef = TypedDict(
    "_RequiredGsmNmrObjTypeDef",
    {
        "Bsic": int,
        "Bcch": int,
    },
)
_OptionalGsmNmrObjTypeDef = TypedDict(
    "_OptionalGsmNmrObjTypeDef",
    {
        "RxLevel": int,
        "GlobalIdentity": GlobalIdentityTypeDef,
    },
    total=False,
)


class GsmNmrObjTypeDef(_RequiredGsmNmrObjTypeDef, _OptionalGsmNmrObjTypeDef):
    pass


ImportedWirelessDeviceTypeDef = TypedDict(
    "ImportedWirelessDeviceTypeDef",
    {
        "Sidewalk": ImportedSidewalkDeviceTypeDef,
    },
    total=False,
)

JoinEventConfigurationTypeDef = TypedDict(
    "JoinEventConfigurationTypeDef",
    {
        "LoRaWAN": LoRaWANJoinEventNotificationConfigurationsTypeDef,
        "WirelessDeviceIdEventTopic": EventNotificationTopicStatusType,
    },
    total=False,
)

JoinResourceTypeEventConfigurationTypeDef = TypedDict(
    "JoinResourceTypeEventConfigurationTypeDef",
    {
        "LoRaWAN": LoRaWANJoinResourceTypeEventConfigurationTypeDef,
    },
    total=False,
)

ListMulticastGroupsByFuotaTaskResponseTypeDef = TypedDict(
    "ListMulticastGroupsByFuotaTaskResponseTypeDef",
    {
        "NextToken": str,
        "MulticastGroupList": List[MulticastGroupByFuotaTaskTypeDef],
        "ResponseMetadata": "ResponseMetadataTypeDef",
    },
)

ListMulticastGroupsResponseTypeDef = TypedDict(
    "ListMulticastGroupsResponseTypeDef",
    {
        "NextToken": str,
        "MulticastGroupList": List[MulticastGroupTypeDef],
        "ResponseMetadata": "ResponseMetadataTypeDef",
    },
)

ListNetworkAnalyzerConfigurationsResponseTypeDef = TypedDict(
    "ListNetworkAnalyzerConfigurationsResponseTypeDef",
    {
        "NextToken": str,
        "NetworkAnalyzerConfigurationList": List[NetworkAnalyzerConfigurationsTypeDef],
        "ResponseMetadata": "ResponseMetadataTypeDef",
    },
)

ListServiceProfilesResponseTypeDef = TypedDict(
    "ListServiceProfilesResponseTypeDef",
    {
        "NextToken": str,
        "ServiceProfileList": List[ServiceProfileTypeDef],
        "ResponseMetadata": "ResponseMetadataTypeDef",
    },
)

LoRaWANDeviceMetadataTypeDef = TypedDict(
    "LoRaWANDeviceMetadataTypeDef",
    {
        "DevEui": str,
        "FPort": int,
        "DataRate": int,
        "Frequency": int,
        "Timestamp": str,
        "Gateways": List[LoRaWANGatewayMetadataTypeDef],
    },
    total=False,
)

LoRaWANGatewayCurrentVersionTypeDef = TypedDict(
    "LoRaWANGatewayCurrentVersionTypeDef",
    {
        "CurrentVersion": LoRaWANGatewayVersionTypeDef,
    },
    total=False,
)

LoRaWANUpdateGatewayTaskCreateTypeDef = TypedDict(
    "LoRaWANUpdateGatewayTaskCreateTypeDef",
    {
        "UpdateSignature": str,
        "SigKeyCrc": int,
        "CurrentVersion": LoRaWANGatewayVersionTypeDef,
        "UpdateVersion": LoRaWANGatewayVersionTypeDef,
    },
    total=False,
)

LoRaWANUpdateGatewayTaskEntryTypeDef = TypedDict(
    "LoRaWANUpdateGatewayTaskEntryTypeDef",
    {
        "CurrentVersion": LoRaWANGatewayVersionTypeDef,
        "UpdateVersion": LoRaWANGatewayVersionTypeDef,
    },
    total=False,
)

MulticastWirelessMetadataTypeDef = TypedDict(
    "MulticastWirelessMetadataTypeDef",
    {
        "LoRaWAN": LoRaWANMulticastMetadataTypeDef,
    },
    total=False,
)

_RequiredStartFuotaTaskRequestRequestTypeDef = TypedDict(
    "_RequiredStartFuotaTaskRequestRequestTypeDef",
    {
        "Id": str,
    },
)
_OptionalStartFuotaTaskRequestRequestTypeDef = TypedDict(
    "_OptionalStartFuotaTaskRequestRequestTypeDef",
    {
        "LoRaWAN": LoRaWANStartFuotaTaskTypeDef,
    },
    total=False,
)


class StartFuotaTaskRequestRequestTypeDef(
    _RequiredStartFuotaTaskRequestRequestTypeDef, _OptionalStartFuotaTaskRequestRequestTypeDef
):
    pass


_RequiredLteObjTypeDef = TypedDict(
    "_RequiredLteObjTypeDef",
    {
        "Mcc": int,
        "Mnc": int,
        "EutranCid": int,
    },
)
_OptionalLteObjTypeDef = TypedDict(
    "_OptionalLteObjTypeDef",
    {
        "Tac": int,
        "LteLocalId": LteLocalIdTypeDef,
        "LteTimingAdvance": int,
        "Rsrp": int,
        "Rsrq": float,
        "NrCapable": bool,
        "LteNmr": Sequence[LteNmrObjTypeDef],
    },
    total=False,
)


class LteObjTypeDef(_RequiredLteObjTypeDef, _OptionalLteObjTypeDef):
    pass


PositionSolverConfigurationsTypeDef = TypedDict(
    "PositionSolverConfigurationsTypeDef",
    {
        "SemtechGnss": SemtechGnssConfigurationTypeDef,
    },
    total=False,
)

PositionSolverDetailsTypeDef = TypedDict(
    "PositionSolverDetailsTypeDef",
    {
        "SemtechGnss": SemtechGnssDetailTypeDef,
    },
    total=False,
)

_RequiredStartSingleWirelessDeviceImportTaskRequestRequestTypeDef = TypedDict(
    "_RequiredStartSingleWirelessDeviceImportTaskRequestRequestTypeDef",
    {
        "DestinationName": str,
        "Sidewalk": SidewalkSingleStartImportInfoTypeDef,
    },
)
_OptionalStartSingleWirelessDeviceImportTaskRequestRequestTypeDef = TypedDict(
    "_OptionalStartSingleWirelessDeviceImportTaskRequestRequestTypeDef",
    {
        "ClientRequestToken": str,
        "DeviceName": str,
        "Tags": Sequence[TagTypeDef],
    },
    total=False,
)


class StartSingleWirelessDeviceImportTaskRequestRequestTypeDef(
    _RequiredStartSingleWirelessDeviceImportTaskRequestRequestTypeDef,
    _OptionalStartSingleWirelessDeviceImportTaskRequestRequestTypeDef,
):
    pass


_RequiredStartWirelessDeviceImportTaskRequestRequestTypeDef = TypedDict(
    "_RequiredStartWirelessDeviceImportTaskRequestRequestTypeDef",
    {
        "DestinationName": str,
        "Sidewalk": SidewalkStartImportInfoTypeDef,
    },
)
_OptionalStartWirelessDeviceImportTaskRequestRequestTypeDef = TypedDict(
    "_OptionalStartWirelessDeviceImportTaskRequestRequestTypeDef",
    {
        "ClientRequestToken": str,
        "Tags": Sequence[TagTypeDef],
    },
    total=False,
)


class StartWirelessDeviceImportTaskRequestRequestTypeDef(
    _RequiredStartWirelessDeviceImportTaskRequestRequestTypeDef,
    _OptionalStartWirelessDeviceImportTaskRequestRequestTypeDef,
):
    pass


UpdatePartnerAccountRequestRequestTypeDef = TypedDict(
    "UpdatePartnerAccountRequestRequestTypeDef",
    {
        "Sidewalk": SidewalkUpdateAccountTypeDef,
        "PartnerAccountId": str,
        "PartnerType": Literal["Sidewalk"],
    },
)

UpdateWirelessDeviceImportTaskRequestRequestTypeDef = TypedDict(
    "UpdateWirelessDeviceImportTaskRequestRequestTypeDef",
    {
        "Id": str,
        "Sidewalk": SidewalkUpdateImportInfoTypeDef,
    },
)

_RequiredTdscdmaObjTypeDef = TypedDict(
    "_RequiredTdscdmaObjTypeDef",
    {
        "Mcc": int,
        "Mnc": int,
        "UtranCid": int,
    },
)
_OptionalTdscdmaObjTypeDef = TypedDict(
    "_OptionalTdscdmaObjTypeDef",
    {
        "Lac": int,
        "TdscdmaLocalId": TdscdmaLocalIdTypeDef,
        "TdscdmaTimingAdvance": int,
        "Rscp": int,
        "PathLoss": int,
        "TdscdmaNmr": Sequence[TdscdmaNmrObjTypeDef],
    },
    total=False,
)


class TdscdmaObjTypeDef(_RequiredTdscdmaObjTypeDef, _OptionalTdscdmaObjTypeDef):
    pass


_RequiredWcdmaObjTypeDef = TypedDict(
    "_RequiredWcdmaObjTypeDef",
    {
        "Mcc": int,
        "Mnc": int,
        "UtranCid": int,
    },
)
_OptionalWcdmaObjTypeDef = TypedDict(
    "_OptionalWcdmaObjTypeDef",
    {
        "Lac": int,
        "WcdmaLocalId": WcdmaLocalIdTypeDef,
        "Rscp": int,
        "PathLoss": int,
        "WcdmaNmr": Sequence[WcdmaNmrObjTypeDef],
    },
    total=False,
)


class WcdmaObjTypeDef(_RequiredWcdmaObjTypeDef, _OptionalWcdmaObjTypeDef):
    pass


_RequiredWirelessDeviceLogOptionTypeDef = TypedDict(
    "_RequiredWirelessDeviceLogOptionTypeDef",
    {
        "Type": WirelessDeviceTypeType,
        "LogLevel": LogLevelType,
    },
)
_OptionalWirelessDeviceLogOptionTypeDef = TypedDict(
    "_OptionalWirelessDeviceLogOptionTypeDef",
    {
        "Events": List[WirelessDeviceEventLogOptionTypeDef],
    },
    total=False,
)


class WirelessDeviceLogOptionTypeDef(
    _RequiredWirelessDeviceLogOptionTypeDef, _OptionalWirelessDeviceLogOptionTypeDef
):
    pass


_RequiredWirelessGatewayLogOptionTypeDef = TypedDict(
    "_RequiredWirelessGatewayLogOptionTypeDef",
    {
        "Type": Literal["LoRaWAN"],
        "LogLevel": LogLevelType,
    },
)
_OptionalWirelessGatewayLogOptionTypeDef = TypedDict(
    "_OptionalWirelessGatewayLogOptionTypeDef",
    {
        "Events": List[WirelessGatewayEventLogOptionTypeDef],
    },
    total=False,
)


class WirelessGatewayLogOptionTypeDef(
    _RequiredWirelessGatewayLogOptionTypeDef, _OptionalWirelessGatewayLogOptionTypeDef
):
    pass


_RequiredCreateWirelessGatewayRequestRequestTypeDef = TypedDict(
    "_RequiredCreateWirelessGatewayRequestRequestTypeDef",
    {
        "LoRaWAN": LoRaWANGatewayTypeDef,
    },
)
_OptionalCreateWirelessGatewayRequestRequestTypeDef = TypedDict(
    "_OptionalCreateWirelessGatewayRequestRequestTypeDef",
    {
        "Name": str,
        "Description": str,
        "Tags": Sequence[TagTypeDef],
        "ClientRequestToken": str,
    },
    total=False,
)


class CreateWirelessGatewayRequestRequestTypeDef(
    _RequiredCreateWirelessGatewayRequestRequestTypeDef,
    _OptionalCreateWirelessGatewayRequestRequestTypeDef,
):
    pass


GetWirelessGatewayResponseTypeDef = TypedDict(
    "GetWirelessGatewayResponseTypeDef",
    {
        "Name": str,
        "Id": str,
        "Description": str,
        "LoRaWAN": LoRaWANGatewayTypeDef,
        "Arn": str,
        "ThingName": str,
        "ThingArn": str,
        "ResponseMetadata": "ResponseMetadataTypeDef",
    },
)

WirelessGatewayStatisticsTypeDef = TypedDict(
    "WirelessGatewayStatisticsTypeDef",
    {
        "Arn": str,
        "Id": str,
        "Name": str,
        "Description": str,
        "LoRaWAN": LoRaWANGatewayTypeDef,
        "LastUplinkReceivedAt": str,
    },
    total=False,
)

WirelessDeviceStatisticsTypeDef = TypedDict(
    "WirelessDeviceStatisticsTypeDef",
    {
        "Arn": str,
        "Id": str,
        "Type": WirelessDeviceTypeType,
        "Name": str,
        "DestinationName": str,
        "LastUplinkReceivedAt": str,
        "LoRaWAN": LoRaWANListDeviceTypeDef,
        "Sidewalk": SidewalkListDeviceTypeDef,
        "FuotaDeviceStatus": FuotaDeviceStatusType,
        "MulticastDeviceStatus": str,
        "McGroupId": int,
    },
    total=False,
)

GetDeviceProfileResponseTypeDef = TypedDict(
    "GetDeviceProfileResponseTypeDef",
    {
        "Arn": str,
        "Name": str,
        "Id": str,
        "LoRaWAN": LoRaWANDeviceProfileTypeDef,
        "Sidewalk": SidewalkGetDeviceProfileTypeDef,
        "ResponseMetadata": "ResponseMetadataTypeDef",
    },
)

LoRaWANDeviceTypeDef = TypedDict(
    "LoRaWANDeviceTypeDef",
    {
        "DevEui": str,
        "DeviceProfileId": str,
        "ServiceProfileId": str,
        "OtaaV1_1": OtaaV11TypeDef,
        "OtaaV1_0_x": OtaaV10XTypeDef,
        "AbpV1_1": AbpV11TypeDef,
        "AbpV1_0_x": AbpV10XTypeDef,
        "FPorts": FPortsTypeDef,
    },
    total=False,
)

LoRaWANUpdateDeviceTypeDef = TypedDict(
    "LoRaWANUpdateDeviceTypeDef",
    {
        "DeviceProfileId": str,
        "ServiceProfileId": str,
        "AbpV1_1": UpdateAbpV11TypeDef,
        "AbpV1_0_x": UpdateAbpV10XTypeDef,
        "FPorts": UpdateFPortsTypeDef,
    },
    total=False,
)

LoRaWANSendDataToDeviceTypeDef = TypedDict(
    "LoRaWANSendDataToDeviceTypeDef",
    {
        "FPort": int,
        "ParticipatingGateways": ParticipatingGatewaysTypeDef,
    },
    total=False,
)

ListWirelessDeviceImportTasksResponseTypeDef = TypedDict(
    "ListWirelessDeviceImportTasksResponseTypeDef",
    {
        "NextToken": str,
        "WirelessDeviceImportTaskList": List[WirelessDeviceImportTaskTypeDef],
        "ResponseMetadata": "ResponseMetadataTypeDef",
    },
)

_RequiredGsmObjTypeDef = TypedDict(
    "_RequiredGsmObjTypeDef",
    {
        "Mcc": int,
        "Mnc": int,
        "Lac": int,
        "GeranCid": int,
    },
)
_OptionalGsmObjTypeDef = TypedDict(
    "_OptionalGsmObjTypeDef",
    {
        "GsmLocalId": GsmLocalIdTypeDef,
        "GsmTimingAdvance": int,
        "RxLevel": int,
        "GsmNmr": Sequence[GsmNmrObjTypeDef],
    },
    total=False,
)


class GsmObjTypeDef(_RequiredGsmObjTypeDef, _OptionalGsmObjTypeDef):
    pass


ListDevicesForWirelessDeviceImportTaskResponseTypeDef = TypedDict(
    "ListDevicesForWirelessDeviceImportTaskResponseTypeDef",
    {
        "NextToken": str,
        "DestinationName": str,
        "ImportedWirelessDeviceList": List[ImportedWirelessDeviceTypeDef],
        "ResponseMetadata": "ResponseMetadataTypeDef",
    },
)

EventNotificationItemConfigurationsTypeDef = TypedDict(
    "EventNotificationItemConfigurationsTypeDef",
    {
        "DeviceRegistrationState": DeviceRegistrationStateEventConfigurationTypeDef,
        "Proximity": ProximityEventConfigurationTypeDef,
        "Join": JoinEventConfigurationTypeDef,
        "ConnectionStatus": ConnectionStatusEventConfigurationTypeDef,
        "MessageDeliveryStatus": MessageDeliveryStatusEventConfigurationTypeDef,
    },
    total=False,
)

GetResourceEventConfigurationResponseTypeDef = TypedDict(
    "GetResourceEventConfigurationResponseTypeDef",
    {
        "DeviceRegistrationState": DeviceRegistrationStateEventConfigurationTypeDef,
        "Proximity": ProximityEventConfigurationTypeDef,
        "Join": JoinEventConfigurationTypeDef,
        "ConnectionStatus": ConnectionStatusEventConfigurationTypeDef,
        "MessageDeliveryStatus": MessageDeliveryStatusEventConfigurationTypeDef,
        "ResponseMetadata": "ResponseMetadataTypeDef",
    },
)

_RequiredUpdateResourceEventConfigurationRequestRequestTypeDef = TypedDict(
    "_RequiredUpdateResourceEventConfigurationRequestRequestTypeDef",
    {
        "Identifier": str,
        "IdentifierType": IdentifierTypeType,
    },
)
_OptionalUpdateResourceEventConfigurationRequestRequestTypeDef = TypedDict(
    "_OptionalUpdateResourceEventConfigurationRequestRequestTypeDef",
    {
        "PartnerType": Literal["Sidewalk"],
        "DeviceRegistrationState": DeviceRegistrationStateEventConfigurationTypeDef,
        "Proximity": ProximityEventConfigurationTypeDef,
        "Join": JoinEventConfigurationTypeDef,
        "ConnectionStatus": ConnectionStatusEventConfigurationTypeDef,
        "MessageDeliveryStatus": MessageDeliveryStatusEventConfigurationTypeDef,
    },
    total=False,
)


class UpdateResourceEventConfigurationRequestRequestTypeDef(
    _RequiredUpdateResourceEventConfigurationRequestRequestTypeDef,
    _OptionalUpdateResourceEventConfigurationRequestRequestTypeDef,
):
    pass


GetEventConfigurationByResourceTypesResponseTypeDef = TypedDict(
    "GetEventConfigurationByResourceTypesResponseTypeDef",
    {
        "DeviceRegistrationState": DeviceRegistrationStateResourceTypeEventConfigurationTypeDef,
        "Proximity": ProximityResourceTypeEventConfigurationTypeDef,
        "Join": JoinResourceTypeEventConfigurationTypeDef,
        "ConnectionStatus": ConnectionStatusResourceTypeEventConfigurationTypeDef,
        "MessageDeliveryStatus": MessageDeliveryStatusResourceTypeEventConfigurationTypeDef,
        "ResponseMetadata": "ResponseMetadataTypeDef",
    },
)

UpdateEventConfigurationByResourceTypesRequestRequestTypeDef = TypedDict(
    "UpdateEventConfigurationByResourceTypesRequestRequestTypeDef",
    {
        "DeviceRegistrationState": DeviceRegistrationStateResourceTypeEventConfigurationTypeDef,
        "Proximity": ProximityResourceTypeEventConfigurationTypeDef,
        "Join": JoinResourceTypeEventConfigurationTypeDef,
        "ConnectionStatus": ConnectionStatusResourceTypeEventConfigurationTypeDef,
        "MessageDeliveryStatus": MessageDeliveryStatusResourceTypeEventConfigurationTypeDef,
    },
    total=False,
)

GetWirelessDeviceStatisticsResponseTypeDef = TypedDict(
    "GetWirelessDeviceStatisticsResponseTypeDef",
    {
        "WirelessDeviceId": str,
        "LastUplinkReceivedAt": str,
        "LoRaWAN": LoRaWANDeviceMetadataTypeDef,
        "Sidewalk": SidewalkDeviceMetadataTypeDef,
        "ResponseMetadata": "ResponseMetadataTypeDef",
    },
)

GetWirelessGatewayFirmwareInformationResponseTypeDef = TypedDict(
    "GetWirelessGatewayFirmwareInformationResponseTypeDef",
    {
        "LoRaWAN": LoRaWANGatewayCurrentVersionTypeDef,
        "ResponseMetadata": "ResponseMetadataTypeDef",
    },
)

UpdateWirelessGatewayTaskCreateTypeDef = TypedDict(
    "UpdateWirelessGatewayTaskCreateTypeDef",
    {
        "UpdateDataSource": str,
        "UpdateDataRole": str,
        "LoRaWAN": LoRaWANUpdateGatewayTaskCreateTypeDef,
    },
    total=False,
)

UpdateWirelessGatewayTaskEntryTypeDef = TypedDict(
    "UpdateWirelessGatewayTaskEntryTypeDef",
    {
        "Id": str,
        "LoRaWAN": LoRaWANUpdateGatewayTaskEntryTypeDef,
        "Arn": str,
    },
    total=False,
)

SendDataToMulticastGroupRequestRequestTypeDef = TypedDict(
    "SendDataToMulticastGroupRequestRequestTypeDef",
    {
        "Id": str,
        "PayloadData": str,
        "WirelessMetadata": MulticastWirelessMetadataTypeDef,
    },
)

_RequiredPutPositionConfigurationRequestRequestTypeDef = TypedDict(
    "_RequiredPutPositionConfigurationRequestRequestTypeDef",
    {
        "ResourceIdentifier": str,
        "ResourceType": PositionResourceTypeType,
    },
)
_OptionalPutPositionConfigurationRequestRequestTypeDef = TypedDict(
    "_OptionalPutPositionConfigurationRequestRequestTypeDef",
    {
        "Solvers": PositionSolverConfigurationsTypeDef,
        "Destination": str,
    },
    total=False,
)


class PutPositionConfigurationRequestRequestTypeDef(
    _RequiredPutPositionConfigurationRequestRequestTypeDef,
    _OptionalPutPositionConfigurationRequestRequestTypeDef,
):
    pass


GetPositionConfigurationResponseTypeDef = TypedDict(
    "GetPositionConfigurationResponseTypeDef",
    {
        "Solvers": PositionSolverDetailsTypeDef,
        "Destination": str,
        "ResponseMetadata": "ResponseMetadataTypeDef",
    },
)

PositionConfigurationItemTypeDef = TypedDict(
    "PositionConfigurationItemTypeDef",
    {
        "ResourceIdentifier": str,
        "ResourceType": PositionResourceTypeType,
        "Solvers": PositionSolverDetailsTypeDef,
        "Destination": str,
    },
    total=False,
)

GetLogLevelsByResourceTypesResponseTypeDef = TypedDict(
    "GetLogLevelsByResourceTypesResponseTypeDef",
    {
        "DefaultLogLevel": LogLevelType,
        "WirelessGatewayLogOptions": List[WirelessGatewayLogOptionTypeDef],
        "WirelessDeviceLogOptions": List[WirelessDeviceLogOptionTypeDef],
        "ResponseMetadata": "ResponseMetadataTypeDef",
    },
)

UpdateLogLevelsByResourceTypesRequestRequestTypeDef = TypedDict(
    "UpdateLogLevelsByResourceTypesRequestRequestTypeDef",
    {
        "DefaultLogLevel": LogLevelType,
        "WirelessDeviceLogOptions": Sequence[WirelessDeviceLogOptionTypeDef],
        "WirelessGatewayLogOptions": Sequence[WirelessGatewayLogOptionTypeDef],
    },
    total=False,
)

ListWirelessGatewaysResponseTypeDef = TypedDict(
    "ListWirelessGatewaysResponseTypeDef",
    {
        "NextToken": str,
        "WirelessGatewayList": List[WirelessGatewayStatisticsTypeDef],
        "ResponseMetadata": "ResponseMetadataTypeDef",
    },
)

ListWirelessDevicesResponseTypeDef = TypedDict(
    "ListWirelessDevicesResponseTypeDef",
    {
        "NextToken": str,
        "WirelessDeviceList": List[WirelessDeviceStatisticsTypeDef],
        "ResponseMetadata": "ResponseMetadataTypeDef",
    },
)

_RequiredCreateWirelessDeviceRequestRequestTypeDef = TypedDict(
    "_RequiredCreateWirelessDeviceRequestRequestTypeDef",
    {
        "Type": WirelessDeviceTypeType,
        "DestinationName": str,
    },
)
_OptionalCreateWirelessDeviceRequestRequestTypeDef = TypedDict(
    "_OptionalCreateWirelessDeviceRequestRequestTypeDef",
    {
        "Name": str,
        "Description": str,
        "ClientRequestToken": str,
        "LoRaWAN": LoRaWANDeviceTypeDef,
        "Tags": Sequence[TagTypeDef],
        "Positioning": PositioningConfigStatusType,
        "Sidewalk": SidewalkCreateWirelessDeviceTypeDef,
    },
    total=False,
)


class CreateWirelessDeviceRequestRequestTypeDef(
    _RequiredCreateWirelessDeviceRequestRequestTypeDef,
    _OptionalCreateWirelessDeviceRequestRequestTypeDef,
):
    pass


GetWirelessDeviceResponseTypeDef = TypedDict(
    "GetWirelessDeviceResponseTypeDef",
    {
        "Type": WirelessDeviceTypeType,
        "Name": str,
        "Description": str,
        "DestinationName": str,
        "Id": str,
        "Arn": str,
        "ThingName": str,
        "ThingArn": str,
        "LoRaWAN": LoRaWANDeviceTypeDef,
        "Sidewalk": SidewalkDeviceTypeDef,
        "Positioning": PositioningConfigStatusType,
        "ResponseMetadata": "ResponseMetadataTypeDef",
    },
)

_RequiredUpdateWirelessDeviceRequestRequestTypeDef = TypedDict(
    "_RequiredUpdateWirelessDeviceRequestRequestTypeDef",
    {
        "Id": str,
    },
)
_OptionalUpdateWirelessDeviceRequestRequestTypeDef = TypedDict(
    "_OptionalUpdateWirelessDeviceRequestRequestTypeDef",
    {
        "DestinationName": str,
        "Name": str,
        "Description": str,
        "LoRaWAN": LoRaWANUpdateDeviceTypeDef,
        "Positioning": PositioningConfigStatusType,
    },
    total=False,
)


class UpdateWirelessDeviceRequestRequestTypeDef(
    _RequiredUpdateWirelessDeviceRequestRequestTypeDef,
    _OptionalUpdateWirelessDeviceRequestRequestTypeDef,
):
    pass


DownlinkQueueMessageTypeDef = TypedDict(
    "DownlinkQueueMessageTypeDef",
    {
        "MessageId": str,
        "TransmitMode": int,
        "ReceivedAt": str,
        "LoRaWAN": LoRaWANSendDataToDeviceTypeDef,
    },
    total=False,
)

WirelessMetadataTypeDef = TypedDict(
    "WirelessMetadataTypeDef",
    {
        "LoRaWAN": LoRaWANSendDataToDeviceTypeDef,
        "Sidewalk": SidewalkSendDataToDeviceTypeDef,
    },
    total=False,
)

CellTowersTypeDef = TypedDict(
    "CellTowersTypeDef",
    {
        "Gsm": Sequence[GsmObjTypeDef],
        "Wcdma": Sequence[WcdmaObjTypeDef],
        "Tdscdma": Sequence[TdscdmaObjTypeDef],
        "Lte": Sequence[LteObjTypeDef],
        "Cdma": Sequence[CdmaObjTypeDef],
    },
    total=False,
)

EventConfigurationItemTypeDef = TypedDict(
    "EventConfigurationItemTypeDef",
    {
        "Identifier": str,
        "IdentifierType": IdentifierTypeType,
        "PartnerType": Literal["Sidewalk"],
        "Events": EventNotificationItemConfigurationsTypeDef,
    },
    total=False,
)

_RequiredCreateWirelessGatewayTaskDefinitionRequestRequestTypeDef = TypedDict(
    "_RequiredCreateWirelessGatewayTaskDefinitionRequestRequestTypeDef",
    {
        "AutoCreateTasks": bool,
    },
)
_OptionalCreateWirelessGatewayTaskDefinitionRequestRequestTypeDef = TypedDict(
    "_OptionalCreateWirelessGatewayTaskDefinitionRequestRequestTypeDef",
    {
        "Name": str,
        "Update": UpdateWirelessGatewayTaskCreateTypeDef,
        "ClientRequestToken": str,
        "Tags": Sequence[TagTypeDef],
    },
    total=False,
)


class CreateWirelessGatewayTaskDefinitionRequestRequestTypeDef(
    _RequiredCreateWirelessGatewayTaskDefinitionRequestRequestTypeDef,
    _OptionalCreateWirelessGatewayTaskDefinitionRequestRequestTypeDef,
):
    pass


GetWirelessGatewayTaskDefinitionResponseTypeDef = TypedDict(
    "GetWirelessGatewayTaskDefinitionResponseTypeDef",
    {
        "AutoCreateTasks": bool,
        "Name": str,
        "Update": UpdateWirelessGatewayTaskCreateTypeDef,
        "Arn": str,
        "ResponseMetadata": "ResponseMetadataTypeDef",
    },
)

ListWirelessGatewayTaskDefinitionsResponseTypeDef = TypedDict(
    "ListWirelessGatewayTaskDefinitionsResponseTypeDef",
    {
        "NextToken": str,
        "TaskDefinitions": List[UpdateWirelessGatewayTaskEntryTypeDef],
        "ResponseMetadata": "ResponseMetadataTypeDef",
    },
)

ListPositionConfigurationsResponseTypeDef = TypedDict(
    "ListPositionConfigurationsResponseTypeDef",
    {
        "PositionConfigurationList": List[PositionConfigurationItemTypeDef],
        "NextToken": str,
        "ResponseMetadata": "ResponseMetadataTypeDef",
    },
)

ListQueuedMessagesResponseTypeDef = TypedDict(
    "ListQueuedMessagesResponseTypeDef",
    {
        "NextToken": str,
        "DownlinkQueueMessagesList": List[DownlinkQueueMessageTypeDef],
        "ResponseMetadata": "ResponseMetadataTypeDef",
    },
)

_RequiredSendDataToWirelessDeviceRequestRequestTypeDef = TypedDict(
    "_RequiredSendDataToWirelessDeviceRequestRequestTypeDef",
    {
        "Id": str,
        "TransmitMode": int,
        "PayloadData": str,
    },
)
_OptionalSendDataToWirelessDeviceRequestRequestTypeDef = TypedDict(
    "_OptionalSendDataToWirelessDeviceRequestRequestTypeDef",
    {
        "WirelessMetadata": WirelessMetadataTypeDef,
    },
    total=False,
)


class SendDataToWirelessDeviceRequestRequestTypeDef(
    _RequiredSendDataToWirelessDeviceRequestRequestTypeDef,
    _OptionalSendDataToWirelessDeviceRequestRequestTypeDef,
):
    pass


GetPositionEstimateRequestRequestTypeDef = TypedDict(
    "GetPositionEstimateRequestRequestTypeDef",
    {
        "WiFiAccessPoints": Sequence[WiFiAccessPointTypeDef],
        "CellTowers": CellTowersTypeDef,
        "Ip": IpTypeDef,
        "Gnss": GnssTypeDef,
        "Timestamp": Union[datetime, str],
    },
    total=False,
)

ListEventConfigurationsResponseTypeDef = TypedDict(
    "ListEventConfigurationsResponseTypeDef",
    {
        "NextToken": str,
        "EventConfigurationsList": List[EventConfigurationItemTypeDef],
        "ResponseMetadata": "ResponseMetadataTypeDef",
    },
)
